capture log close
set more off
clear
// Project: Nexus Tax Laws and Economies of Density in E-Commerce: A Study of Amazon’s Fulfillment Center Network
// Authors: Houde, Newberry, Seim
// Created by: Peter Newberry
// Date: 05/2022
// Description: Creates the household level yearly spending data across the three modes
// Data sets needed: transactions_sub_dom.dta: comScore transaction level data (proprietary)
//					 demographics.dta: raw demographics file from comScore (proprietary)
//					 zip_county_match.dta: matches zip codes with the primary county they are in.
//					 county_panel.dta: county demographics, etc., created by authors
//					 State_census_codes.dta: state fips, region, district census codes.
//					 purch_pr.dta: purchase probablity data created from forrester data
//					 Panel_county_tax_dist.dta: has county level tax information as well as information on distances to FCs and SCS. The tax information is propreitary. Souces is TDS (tax data systems).It also has whether or not transacitons in the year/mode are taxable. 
// Author notes: based on author do-file "hh_expenditure_create.do"

*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
//First part creates household/yearly level spending across the three modes of shopping. 


// comscore transaciton level data
use "transactions_sub_dom.dta", clear

// change zappos to mode 1 after aquisition
replace mode=1 if domain_name=="zappos.com" & year>=2009
egen amazon_domain_id=max(domain_id*(domain_name=="amazon.com"))
replace domain_id=amazon_domain_id if domain_name=="zappos.com" & year>=2009
replace domain_name="amazon.com" if domain_name=="zappos.com" & year>=2009

//merge in comscore demo graphic information
sort machine_id year
merge machine_id year using "demographics.dta"
tab _merge
keep if _merge==3

// drop 2004 and 2005
keep if year>=2006
drop _merge
drop if mode==.

// merge in the zip county match
sort zip_code
merge zip_code using "zip_county_match.dta"
tab _merge
keep if _merge==3
drop _merge

// merge in county demos
sort county year
merge m:1 county year using "county_panel.dta"
tab _merge
keep if _merge==3
drop _merge

// merge in state fips as well as region and district number
drop census_region
sort state
merge m:1 state using "State_census_codes.dta"
keep if _merge==3
drop _merge


//rename variabes
rename state state2
rename state_abbrev state

rename census_region region
rename census_division district

//drop HI and AK
drop if state=="AK" | state=="HI"


//merge in tax rates
merge m:1 county_code year using "Panel_county_tax_dist.dta"
tab _merge
keep if _merge==3
drop _merge

//generate applied tax rates for each mode
gen tax2=tax
replace tax2=amazon_tax if mode==1
replace tax2=tax if mode==2
replace tax2=0 if mode==3
replace tax=tax2 
drop tax2

// generate the basket total across all products within a basket
egen tot_price_basket=sum(prod_totprice), by(machine_id site_session_id domain_id basket_tot year mode)

// generate the percentage of the basket total for each product
gen perc_basket=prod_totprice/tot_price_basket


// try to back out shipping charges by subtracting taxes and prices of products from the basket tot variable in comscore
gen ship=basket_tot-tot_price_basket - tax*tot_price_basket 
replace ship=round(ship,.01)

// create a shipping charge per item
egen ship_per=mean(ship), by(machine_id site_session_id domain_id basket_tot year mode)
drop tot_price_basket ship

// round variables to the nearest cent and fix negative shipping
replace prod_totprice=round(prod_totprice, 0.01)
replace ship_per=round(ship_per, 0.01)
replace ship_per=0 if ship_per<=0

// calculate another version of product level prices and drop extreme values.
gen prod_price=basket_tot*perc_basket
replace prod_price=round(prod_price, 0.01)
replace prod_price=. if prod_price<0
replace prod_price=. if prod_price>2000

//net out taxes.
replace prod_price=(1-tax)*prod_price

// generate dummy for media category
gen cat_media=(prod_category_id>=21 & prod_category_id<=24)


// get price moments for media and non media categories
egen ave_tran_price=mean(prod_price), by(machine_id mode year cat_media)
egen med_tran_price=median(prod_price), by(machine_id mode year cat_media)

//get price moments for all categories
egen ave_tran_price_nocat=mean(prod_price), by(machine_id mode year)
egen med_tran_price_nocat=median(prod_price), by(machine_id mode year)

//generate mode level price moments for media and non-media categories 
egen med_tran_price_med1=max(med_tran_price*(mode==1)*(cat_media==1)), by(machine_id year)
egen med_tran_price_med2=max(med_tran_price*(mode==2)*(cat_media==1)), by(machine_id year)
egen med_tran_price_med3=max(med_tran_price*(mode==3)*(cat_media==1)), by(machine_id year)

egen med_tran_price_nmed1=max(med_tran_price*(mode==1)*(cat_media==0)), by(machine_id year)
egen med_tran_price_nmed2=max(med_tran_price*(mode==2)*(cat_media==0)), by(machine_id year)
egen med_tran_price_nmed3=max(med_tran_price*(mode==3)*(cat_media==0)), by(machine_id year)
drop med_tran_price

egen med_tran_price1=max(med_tran_price_nocat*(mode==1)), by(machine_id year)
egen med_tran_price2=max(med_tran_price_nocat*(mode==2)), by(machine_id year)
egen med_tran_price3=max(med_tran_price_nocat*(mode==3)), by(machine_id year)
drop med_tran_price_nocat

egen ave_tran_price_med1=max(ave_tran_price*(mode==1)*(cat_media==1)), by(machine_id year)
egen ave_tran_price_med2=max(ave_tran_price*(mode==2)*(cat_media==1)), by(machine_id year)
egen ave_tran_price_med3=max(ave_tran_price*(mode==3)*(cat_media==1)), by(machine_id year)

egen ave_tran_price_nmed1=max(ave_tran_price*(mode==1)*(cat_media==0)), by(machine_id year)
egen ave_tran_price_nmed2=max(ave_tran_price*(mode==2)*(cat_media==0)), by(machine_id year)
egen ave_tran_price_nmed3=max(ave_tran_price*(mode==3)*(cat_media==0)), by(machine_id year)
drop ave_tran_price

egen ave_tran_price1=max(ave_tran_price_nocat*(mode==1)), by(machine_id year)
egen ave_tran_price2=max(ave_tran_price_nocat*(mode==2)), by(machine_id year)
egen ave_tran_price3=max(ave_tran_price_nocat*(mode==3)), by(machine_id year)
drop ave_tran_price_nocat


// contract everything at the transaction level (aggregate across products within a basket)
contract machine_id site_session_id domain_id domain_name basket_tot year mode ave_tran* med_tran*

// number of products in the transaction
rename _freq prods

// generate a data set that is the average products per order for each mode/year
preserve
egen prods_per=mean(prods), by(mode year)
contract mode year prods_per
drop _freq
egen prods_per1=max(prods_per*(mode==1)), by(year)
egen prods_per2=max(prods_per*(mode==2)), by(year)
egen prods_per3=max(prods_per*(mode==3)), by(year)
contract year prods_per1 prods_per2 prods_per3
drop _freq
save "product_per_order.dta", replace
restore


// caclulate total expenditures on each mode in each year for all households
egen tot_exp1=sum(basket_tot*(mode==1)), by(machine_id year)
egen tot_exp2=sum(basket_tot*(mode==2)), by(machine_id year)
egen tot_exp3=sum(basket_tot*(mode==3)), by(machine_id year)
drop basket_tot

// calalate total transactions on each mode in each year for all households
gen dum=1
egen tot_tran1=sum(dum*(mode==1)), by(machine_id year)
egen tot_tran2=sum(dum*(mode==2)), by(machine_id year)
egen tot_tran3=sum(dum*(mode==3)), by(machine_id year)

// calalate total products on each mode in each year for all households
egen tot_prods1=sum(prods*(mode==1)), by(machine_id year)
egen tot_prods2=sum(prods*(mode==2)), by(machine_id year)
egen tot_prods3=sum(prods*(mode==3)), by(machine_id year)
drop prods


//merge in demograhpic data from comescore (again because contracted that information away)
sort machine_id year
merge machine_id year using "demographics.dta"
tab _merge
drop if _merge==1
keep if year>=2006


// expenditures and transactions are 0 for households in the demo panel but not in the transaction data.
replace tot_exp1=0 if _merge==2
replace tot_exp2=0 if _merge==2
replace tot_exp3=0 if _merge==2

replace tot_tran1=0 if _merge==2
replace tot_tran2=0 if _merge==2
replace tot_tran3=0 if _merge==2

// drop people who have 0 expenditures (end up using forrester data to account for this)
drop if tot_exp1==0 & tot_exp2==0 & tot_exp3==0
drop _merge

// merge in the zip county match
sort zip_code
merge zip_code using "zip_county_match.dta"
tab _merge
keep if _merge==3
drop _merge

// merge in county demos
sort county year
merge m:1 county year using "county_panel.dta"
tab _merge
keep if _merge==3
drop _merge

// merge in state fips as well as region and district number
drop census_region
sort state
merge m:1 state using "State_census_codes.dta"
keep if _merge==3
drop _merge

rename state state2
rename state_abbrev state

rename census_region region
rename census_division district


// collapse every thing to the household/year level
collapse (mean) tot_exp* tot_tran* tot_prods* med_tran* ave_tran* , by(machine_id year state county region district)

// drop outliears
egen p1=pctile(tot_exp1), by(year) p(1)
egen p99=pctile(tot_exp1), by(year)  p(99)
keep if tot_exp1>=p1 & tot_exp1<=p99
drop p1 p99
egen p1=pctile(tot_exp2), by(year) p(1)
egen p99=pctile(tot_exp2), by(year) p(99)
keep if tot_exp2>=p1 & tot_exp2<=p99
drop p1 p99
egen p1=pctile(tot_exp3), by(year) p(1)
egen p99=pctile(tot_exp3), by(year) p(99)
keep if tot_exp3>=p1 & tot_exp3<=p99

//merge in demograhpic data from comescore (for the third time because contracted that information away)
sort machine_id year
merge machine_id year using "demographics.dta"
tab _merge
keep if _merge==3
drop _merge

// drop HI AK and PR
drop if state=="PR"
drop if state=="HI"
drop if state=="AK"

// generate demo bins to match other data.
gen age=.
replace age=1 if hoh_oldest_age==1 | hoh_oldest_age==2 
replace age=2 if hoh_oldest_age==3 | hoh_oldest_age==4 | hoh_oldest_age==5 | hoh_oldest_age==6 
replace age=3 if hoh_oldest_age==7 | hoh_oldest_age==8 | hoh_oldest_age==9 | hoh_oldest_age==10 
replace age=4 if hoh_oldest_age==11 
drop if age==.

gen race=6
replace race=1 if racial_background==1
replace race=2 if racial_background==2
replace race=3 if racial_background==3
replace race=4 if racial_background==5
drop if race==.

gen income_group=household_income
replace income_group=1 if income_group==1 | income_group==2 & year<=2013
replace income_group=2 if income_group==3 | income_group==4 | income_group==5 & year<=2013
replace income_group=3 if income_group==6 & year<=2013
replace income_group=4 if income_group==7 & year<=2013


replace income_group=1 if income_group==11 & year>=2014
replace income_group=2 if income_group==12 | income_group==13 | income_group==14 & year>=2014
replace income_group=3 if income_group==15 & year>=2014
replace income_group=4 if income_group>=16 & year>=2014


// create total expenditures and transactions for each household
gen tot_exp=(tot_exp1+tot_exp2+ tot_exp3)
gen tot_tran=(tot_tran1+tot_tran2+ tot_tran3)

// create total households in each county
gen dum=1
egen tot_hh=sum(dum), by(county)
drop dum


// merge in purchase probabilities from created forrester data set
sort  year age race race income_group state
merge 1:1 machine_id year using "purch_pr.dta"
tab _merge
keep if _merge==3
drop _merge


// create total expenditures weighted by the forrester prob
gen tot_exp1_forr=tot_exp1*purch_pr_adjust
gen tot_exp2_forr=tot_exp2*purch_pr_adjust
gen tot_exp3_forr=tot_exp3*purch_pr_adjust

gen tot_exp_forr=(tot_exp1_forr+tot_exp2_forr+ tot_exp3_forr)

gen tot_tran1_forr=tot_tran1*purch_pr_adjust
gen tot_tran2_forr=tot_tran2*purch_pr_adjust
gen tot_tran3_forr=tot_tran3*purch_pr_adjust

gen tot_tran_forr=(tot_tran1_forr+tot_tran2_forr+ tot_tran3_forr)

gen tot_prods1_forr=tot_prods1*purch_pr_adjust
gen tot_prods2_forr=tot_prods2*purch_pr_adjust
gen tot_prods3_forr=tot_prods3*purch_pr_adjust

gen tot_prods_forr=(tot_prods1_forr+tot_prods2_forr+ tot_prods3_forr)


// save hh_expenditure data. 
save "Data/Processed/Main/hh_expenditures.dta", replace

*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
//Second part creates a comScore "census" file that has the number of people in each demographic group and by geographic location. We combine this with census data in order to create the population weights in order to aggergate the data

preserve
//create the number of people who have positive spending on Amazon and the other modes in each year and county and demographic group.
gen no_amazon_dum=tot_exp1>0 & tot_exp1~=.
egen comscore_hh1=sum(no_amazon_dum), by(year county race age income_group)
replace comscore_hh1=. if comscore_hh1==0

gen no_wm_dum=tot_exp2>0 & tot_exp2~=.
egen comscore_hh2=sum(no_wm_dum), by(year county race age income_group)
replace comscore_hh2=. if comscore_hh2==0

gen no_os_dum=tot_exp3>0 & tot_exp3~=.
egen comscore_hh3=sum(no_os_dum), by(year county race age income_group)
replace comscore_hh3=. if comscore_hh3==0

contract year county race age income_group comscore_*
rename _freq group_tot
rename county fips
sort year fips race age income_group
save "comscr_census.dta", replace
restore

