capture log close
set more off
clear
// Project: Nexus Tax Laws and Economies of Density in E-Commerce: A Study of Amazon’s Fulfillment Center Network
// Authors: Houde, Newberry, Seim
// Created by: Peter Newberry
// Date: 05/2022
// Description: Creates the probabities a household doesn't purchase anything online
// Data sets needed: transactions_sub_dom.dta: comScore transaction level data (proprietary)
//					 demographics.dta: raw demographics file from comScore (proprietary)
//					 zip_county_match.dta: matches zip codes with the primary county they are in.
//					 county_panel.dta: county demographics, etc., created by authors
//					 State_census_codes.dta: state fips, region, district census codes.
//					 county_urban_rural.dta: percentage of county defined as "urban" versus "rural", from the census.
//					 YYYY Dataset.dta: forrester data sets. have 2006-2007 and 2010-2017. other data not available	
// Author notes: based on author do-file "forrester_prob.do" and "forrester_prob_adjust.do"

*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
//First part creates the probablity of a comscore household (based on demos) making a purchase sometime in Q2-Q4 because the forrester survey asks the question in Q1. That is, we use the comscore data to supplement the survey data we have from forresster. 

use "transactions_sub_dom.dta", clear

// replace Zappos to be Amazon after aquisition
replace mode=1 if domain_name=="zappos.com" & year>=2009
egen amazon_domain_id=max(domain_id*(domain_name=="amazon.com"))
replace domain_id=amazon_domain_id if domain_name=="zappos.com" & year>=2009
replace domain_name="amazon.com" if domain_name=="zappos.com" & year>=2009

// merge in demograhpic comScore file, which includes all correspondents. 
sort machine_id year
merge machine_id year using "demographics.dta"
tab _merge

// if in demographic file but not transaction data, assume that the hh had 0 online trasnactions
gen purch_hh=(1-(_merge==2))

// drop 2004-2005 and hhs not in transaction data
drop if _merge==1
keep if year>=2006
drop if mode==. & _merge==3
drop _merge

// merge in county to match each zip code. 
sort zip_code
merge zip_code using "zip_county_match.dta"
tab _merge
keep if _merge==3
drop _merge

// merge in demographic information
sort county year
merge m:1 county year using "county_panel.dta"
tab _merge
keep if _merge==3
drop _merge



/*MERGE IN DISTRICT AND REGION*/
drop census_region
sort state
merge m:1 state using "State_census_codes.dta"
keep if _merge==3
drop _merge

// redefine some variables
rename state state2
rename state_abbrev state

rename census_region region
rename census_division district

// drop AK, HI and PR
drop if state=="AK" | state=="HI" | state=="PR"


// generate demographic bins that match the bins across different comscore samples and the forrester data
gen age=.
replace age=1 if hoh_oldest_age==1 | hoh_oldest_age==2 
replace age=2 if hoh_oldest_age==3 | hoh_oldest_age==4 | hoh_oldest_age==5 | hoh_oldest_age==6 
replace age=3 if hoh_oldest_age==7 | hoh_oldest_age==8 | hoh_oldest_age==9 | hoh_oldest_age==10 
replace age=4 if hoh_oldest_age==11 
drop if age==.

gen race=6
replace race=1 if racial_background==1
replace race=2 if racial_background==2
replace race=3 if racial_background==3
replace race=4 if racial_background==5
drop if race==.

gen income_group=household_income
replace income_group=1 if income_group==1 | income_group==2 & year<=2013
replace income_group=2 if income_group==3 | income_group==4 | income_group==5 & year<=2013
replace income_group=3 if income_group==6 & year<=2013
replace income_group=4 if income_group==7 & year<=2013


replace income_group=1 if income_group==11 & year>=2014
replace income_group=2 if income_group==12 | income_group==13 | income_group==14 & year>=2014
replace income_group=3 if income_group==15 & year>=2014
replace income_group=4 if income_group>=16 & year>=2014

// merge in urban rural data
merge m:1 county using "county_urban_rural.dta"
tab _merge
drop _merge

// change date to a stata data
gen purch_date=date(event_date, "YMD")

// get quarter of purchase
gen quarter=quarter(purch_date)

egen q1=max(quarter==1), by(machine_id year)
egen q2=max(quarter==2), by(machine_id year)

// contract data to a single hh/year 
contract machine_id year q1 q2 purch_hh age race income_group state perc_urban
drop _freq

// create state indicator
egen state_id=group(state)

// generate purch probabilty variable we are going to fill in for comscore data
gen purch_pr_cs=.

// run a regression for each year on data outside of Q1 and then predict prob someone purchases, given a set of demographics, in Q2-Q4
reg purch_hh i.age i.race i.income_group i.state_id perc_urban if q1~=1 & year==2006
predict purch_pr06, xb
replace purch_pr_cs=purch_pr06 if year==2006

reg purch_hh i.age i.race i.income_group i.state_id  perc_urban if q1~=1 & year==2007
predict purch_pr07, xb
replace purch_pr_cs=purch_pr07 if year==2007

reg purch_hh i.age i.race i.income_group i.state_id  perc_urban if q1~=1 & year==2008
predict purch_pr08, xb
replace purch_pr_cs=purch_pr08 if year==2008

reg purch_hh i.age i.race i.income_group i.state_id  perc_urban if q1~=1 & year==2009
predict purch_pr09, xb
replace purch_pr_cs=purch_pr09 if year==2009

reg purch_hh i.age i.race i.income_group i.state_id  perc_urban if q1~=1 & year==2010
predict purch_pr10, xb
replace purch_pr_cs=purch_pr10 if year==2010

reg purch_hh i.age i.race i.income_group i.state_id  perc_urban if q2~=1 & year==2011
predict purch_pr11, xb
replace purch_pr_cs=purch_pr11 if year==2011

reg purch_hh i.age i.race i.income_group i.state_id  perc_urban if q1~=1 & year==2012
predict purch_pr12, xb
replace purch_pr_cs=purch_pr12 if year==2012

reg purch_hh i.age i.race i.income_group i.state_id  perc_urban  if q1~=1 & year==2013
predict purch_pr13, xb
replace purch_pr_cs=purch_pr13 if year==2013

reg purch_hh i.age i.race i.income_group i.state_id  perc_urban  if q1~=1 & year==2014
predict purch_pr14, xb
replace purch_pr_cs=purch_pr14 if year==2014

reg purch_hh i.age i.race i.income_group i.state_id  perc_urban  if q2~=1 & year==2015
predict purch_pr15, xb
replace purch_pr_cs=purch_pr15 if year==2015

reg purch_hh i.age i.race i.income_group i.state_id  perc_urban  if q1~=1 & year==2016
predict purch_pr16, xb
replace purch_pr_cs=purch_pr16 if year==2016

// only keep households that made a purchase because we are going to merge that in with the purhcase data later.
keep if purch_hh==1
contract machine_id year purch_pr_cs 
drop if purch_pr_cs==.

save "purch_pr_adjust.dta", replace


************************************************************************
************************************************************************

//Second Part take ths raw Forrester data, imports it and makes adjustments in order for the data to be consistent across years. 


// 2006 forrester data
use "2006 Dataset.dta", clear

// drop people who answered the question that they don't have internet.
drop if bq53==1 /*DROP IF DON'T HAVE INTERNET*/

// question is whether they bought somethign from home online
gen purch= (bq72_1==1)

// generate demo bins
gen income_group=.
replace income_group=1 if uhhinc<=8
replace income_group=2 if uhhinc>=9 & uhhinc<=23
replace income_group=3 if uhhinc>=24 & uhhinc<=28
replace income_group=4 if uhhinc>=29
drop if income_group==.

gen age=.
replace age=1 if urage>=18 &  urage<=24
replace age=2 if  urage>=25 & urage<=44
replace age=3 if  urage>=45 & urage<=64
replace age=4 if urage>=65
drop if age==.

gen race=.
replace race=1 if urace==1 
replace race=2 if urace==2
replace race=3 if urace==3
replace race=4 if urace==4 
replace race=4 if urace==5
drop if race==.


//merge in county information
rename uzip zip_code
sort zip_code
merge zip_code using "zip_county_match.dta"
tab _merge
keep if _merge==3
drop _merge


// generate and rename vars.
gen year=2006
rename A_weight weight
keep zip_code county purch age race income_group weight year

// save data.
save "forr_2006_tmp.dta", replace

*****************************************************
// 2007 forrester data
use "2007 Dataset.dta", clear

// question is whether they bought somethign from home online
gen purch= (Q_71_1==1)

// generate demo variables and demo bins
rename Q_urage urage
rename Q_urace urace
rename Q_uhhinc uhhinc

rename Q_uzip uzip
rename Q_wgthh weight

gen income_group=.
replace income_group=1 if uhhinc<=8
replace income_group=2 if uhhinc>=9 & uhhinc<=23
replace income_group=3 if uhhinc>=24 & uhhinc<=28
replace income_group=4 if uhhinc>=29
drop if income_group==.

gen age=.
replace age=1 if urage>=18 &  urage<=24
replace age=2 if  urage>=25 & urage<=44
replace age=3 if  urage>=45 & urage<=64
replace age=4 if urage>=65
drop if age==.

gen race=.
replace race=1 if urace==1 
replace race=2 if urace==2
replace race=3 if urace==3
replace race=4 if urace==4 
replace race=4 if urace==5
drop if race==.

//merge in county information
rename uzip zip_code
sort zip_code
merge zip_code using "zip_county_match.dta"
tab _merge
keep if _merge==3
drop _merge

// generate and rename vars.
gen year=2007

keep zip_code county purch age race income_group weight year

// save data.
save "forr_2007_tmp.dta"  , replace

*****************************************************

//2010 forrester data
use "2010 Dataset.dta", clear

// question is whether they bought something online
gen purch= (Qb36_1==1) | (Qb36_2==1)

// generate demo variables and demo bins
rename Qb03_S urage
rename Qb73_DM uzip

gen income_group=.
replace income_group=1 if Qb82_DM<=22499.5
replace income_group=2 if Qb82_DM>22499.5 & Qb82_DM<=72499.5
replace income_group=3 if Qb82_DM>72499.5 & Qb82_DM<=97499.5
replace income_group=4 if Qb82_DM>97499.5
drop if income_group==.


gen age=.
replace age=1 if urage>=18 &  urage<=24
replace age=2 if  urage>=25 & urage<=44
replace age=3 if  urage>=45 & urage<=64
replace age=4 if urage>=65
drop if age==.

gen race=.
replace race=1 if Qb80_DM==7 
replace race=2 if Qb80_DM==2
replace race=3 if Qb80_DM==3 | Qb80_DM==6  
replace race=4 if Qb80_DM==1 | Qb80_DM==4 | Qb80_DM==5 | Qb80_DM==8 
drop if race==.

//merge in county information
rename uzip zip_code
sort zip_code
merge zip_code using "zip_county_match.dta"
tab _merge
keep if _merge==3
drop _merge

// generate and rename vars.
gen year=2010


keep zip_code county purch age race income_group weight year

// save data.
save "forr_2010_tmp.dta", replace


*****************************************************

//2011 forrester data
use "2011 Dataset.dta", clear

// question is whether they bought something online
gen purch= (Qb_26_01==1) | (Qb_26_02==1)


// generate demo variables and demo bins
rename Qb_04_S urage
rename Qb_3U_DM_new uzip
rename Qb_weight weight

gen income_group=.
replace income_group=1 if Qb_80_DM<=22499.5
replace income_group=2 if Qb_80_DM>22499.5 & Qb_80_DM<=72499.5
replace income_group=3 if Qb_80_DM>72499.5 & Qb_80_DM<=97499.5
replace income_group=4 if Qb_80_DM>97499.5
drop if income_group==.

gen age=.
replace age=1 if urage>=18 &  urage<=24
replace age=2 if  urage>=25 & urage<=44
replace age=3 if  urage>=45 & urage<=64
replace age=4 if urage>=65
drop if age==.

gen race=.
replace race=1 if Qb_76U_07_DM==1 
replace race=2 if Qb_76U_02_DM==1
replace race=3 if Qb_76U_06_DM==1 | Qb_76U_03_DM==1  
replace race=4 if Qb_76U_01_DM==1 | Qb_76U_04_DM==1 | Qb_76U_05_DM==1 | Qb_76U_08_DM==1 
drop if race==.

//merge in county information
rename uzip zip_code
sort zip_code
merge zip_code using "zip_county_match.dta"
tab _merge
keep if _merge==3
drop _merge

// generate and rename vars.
gen year=2011


keep zip_code county purch age race income_group weight year

save "forr_2011_tmp.dta" , replace


*****************************************************

// 2012 data
use "2012 Dataset.dta", clear

// question is whether they bought something online
gen purch= (QB_17_01_RE==1) | (QB_17_02_RE==1)


// generate demo variables and demo bins
rename QB_05_S urage
rename QB_zip uzip
rename QB_weight weight

gen income_group=.
replace income_group=1 if QB_74_DM<=22499.5
replace income_group=2 if QB_74_DM>22499.5 & QB_74_DM<=72499.5
replace income_group=3 if QB_74_DM>72499.5 & QB_74_DM<=97499.5
replace income_group=4 if QB_74_DM>97499.5
drop if income_group==.


gen age=.
replace age=1 if urage>=18 &  urage<=24
replace age=2 if  urage>=25 & urage<=44
replace age=3 if  urage>=45 & urage<=64
replace age=4 if urage>=65
drop if age==.

gen race=.
replace race=1 if QB_65_07_DM_US==1
replace race=2 if QB_65_02_DM_US==1
replace race=3 if QB_65_06_DM_US==1 | QB_65_03_DM_US==1 
replace race=4 if QB_65_01_DM_US==1 | QB_65_04_DM_US==1 | QB_65_05_DM_US==1 | QB_65_08_DM_US==1 
drop if race==.


//merge in county information
rename uzip zip_code
sort zip_code
merge zip_code using "zip_county_match.dta"
tab _merge
keep if _merge==3
drop _merge


// generate and rename vars.
gen year=2012



keep zip_code county purch age race income_group weight year

save "forr_2012_tmp.dta" , replace


*****************************************************

//2013 data
use "2013 Dataset.dta", clear

// question is whether they bought something online
gen purch= (QB_20_02_RE==1) | (QB_20_03_RE==1)


// generate demo variables and demo bins
rename QB_03_S urage
rename zip uzip
rename QB_weight1 weight


gen income_group=.
replace income_group=1 if QB_63_DM_NA<=22499.5
replace income_group=2 if QB_63_DM_NA>22499.5 & QB_63_DM_NA<=72499.5
replace income_group=3 if QB_63_DM_NA>72499.5 & QB_63_DM_NA<=97499.5
replace income_group=4 if QB_63_DM_NA>97499.5
drop if income_group==.

gen age=.
replace age=1 if urage>=18 &  urage<=24
replace age=2 if  urage>=25 & urage<=44
replace age=3 if  urage>=45 & urage<=64
replace age=4 if urage>=65
drop if age==.

gen race=.
replace race=1 if QB_66_07_DM_US==1
replace race=2 if QB_66_02_DM_US==1
replace race=3 if QB_66_06_DM_US==1 | QB_66_03_DM_US==1 
replace race=4 if QB_66_01_DM_US==1 | QB_66_04_DM_US==1 | QB_66_05_DM_US==1 | QB_66_08_DM_US==1 
drop if race==.

//merge in county information
rename uzip zip_code
sort zip_code
merge zip_code using "zip_county_match.dta"
tab _merge
keep if _merge==3
drop _merge

// generate and rename vars.
gen year=2013



keep zip_code county purch age race income_group weight year

save "forr_2013_tmp.dta", replace


*****************************************************

//2014 data
use "2014 Dataset.dta", clear

// question is whether they bought something online
gen purch= (QB_20_02_RE==1) | (QB_20_03_RE==1)



// generate demo variables and demo bins
rename QB_03_S urage
gen age=.
replace age=1 if urage>=18 &  urage<=24
replace age=2 if  urage>=25 & urage<=44
replace age=3 if  urage>=45 & urage<=64
replace age=4 if urage>=65
drop if age==.

/*DIFFERENT STRUCTURE THAN THE PREVIOUS DATA SETS. MANY MORE GROUPS*/
gen race=.
replace race=1 if QB_68_07_DM==1
replace race=2 if QB_68_02_DM==1
replace race=3 if QB_68_06_DM==1 | QB_68_03_DM==1 
replace race=4 if QB_68_01_DM==1 | QB_68_04_DM==1 | QB_68_05_DM==1 | QB_68_08_DM==1 
drop if race==.


gen income_group=.
replace income_group=1 if  QB_65_DM_NA<=22499.5
replace income_group=2 if  QB_65_DM_NA>22499.5 &  QB_65_DM_NA<=72499.5
replace income_group=3 if  QB_65_DM_NA>72499.5 &  QB_65_DM_NA<=97499.5
replace income_group=4 if  QB_65_DM_NA>97499.5
drop if income_group==.

rename zip uzip
rename QB_weight1_NA weight
keep uzip purch age race income_group weight

//merge in county information
rename uzip zip_code
sort zip_code
merge zip_code using "zip_county_match.dta"
tab _merge
keep if _merge==3
drop _merge

// generate and rename vars.
gen year=2014



keep zip_code county purch age race income_group weight year

save "forr_2014_tmp.dta", replace


*****************************************************

//2015 data
use "2015dataset.dta", clear

// question is whether they bought something online
gen purch= (QB_20_02_RE==1) | (QB_20_03_RE==1)



// generate demo variables and demo bins
rename QB_03_S urage
gen age=.
replace age=1 if urage>=18 &  urage<=24
replace age=2 if  urage>=25 & urage<=44
replace age=3 if  urage>=45 & urage<=64
replace age=4 if urage>=65
drop if age==.

gen race=.
replace race=1 if QB_68B_01_DM==1
replace race=2 if QB_68B_02_DM==1
replace race=3 if QB_68B_04_DM==1
replace race=4 if QB_68B_03_DM==1 | QB_68B_05_DM==1 | QB_68B_97_DM==1
drop if race==.


gen income_group=.
replace income_group=1 if  QB_65_DM_NA<=22499.5
replace income_group=2 if  QB_65_DM_NA>22499.5 &  QB_65_DM_NA<=72499.5
replace income_group=3 if  QB_65_DM_NA>72499.5 &  QB_65_DM_NA<=97499.5
replace income_group=4 if  QB_65_DM_NA>97499.5
drop if income_group==.


rename zip uzip
rename QB_weight1_NA weight
keep uzip purch age race income_group weight

//merge in county information
rename uzip zip_code
sort zip_code
merge zip_code using "zip_county_match.dta"
tab _merge
keep if _merge==3
drop _merge

// generate and rename vars.
gen year=2015


keep zip_code county purch age race income_group weight year

save "forr_2015_tmp.dta", replace


*****************************************************

//2016 data
use "2016dataset.dta", clear

// question is whether they bought something online
gen purch= (QB_20_02_RE==1) | (QB_20_03_RE==1)

// generate demo variables and demo bins
rename QB_03_S urage
gen age=.
replace age=1 if urage>=18 &  urage<=24
replace age=2 if  urage>=25 & urage<=44
replace age=3 if  urage>=45 & urage<=64
replace age=4 if urage>=65
drop if age==.

gen race=.
replace race=1 if QB_66B_01_DM_US==1
replace race=2 if QB_66B_02_DM_US==1
replace race=3 if QB_66B_04_DM_US==1
replace race=4 if QB_66B_03_DM_US==1 | QB_66B_05_DM_US==1 | QB_66B_97_DM_US==1
drop if race==.


gen income_group=.
replace income_group=1 if  QB_63_DM_NA<=22499.5
replace income_group=2 if  QB_63_DM_NA>22499.5 &  QB_63_DM_NA<=72499.5
replace income_group=3 if  QB_63_DM_NA>72499.5 &  QB_63_DM_NA<=97499.5
replace income_group=4 if  QB_63_DM_NA>97499.5
drop if income_group==.


rename zip uzip
rename QB_weight1_NA weight
keep uzip purch age race income_group weight


//merge in county information
rename uzip zip_code
sort zip_code
merge zip_code using "zip_county_match.dta"
tab _merge
keep if _merge==3
drop _merge

// generate and rename vars.
gen year=2016



keep zip_code county purch age race income_group weight year

save "forr_2016_tmp.dta", replace


*****************************************************

//2017 data
use "2017dataset.dta", clear

// question is whether they bought something online
gen purch= (QB_19_03_RE==1)


// generate demo variables and demo bins
rename QB_03_S urage
gen age=.
replace age=1 if urage>=18 &  urage<=24
replace age=2 if  urage>=25 & urage<=44
replace age=3 if  urage>=45 & urage<=64
replace age=4 if urage>=65
drop if age==.

gen race=.
replace race=1 if QB_65B_01_DM==1
replace race=2 if QB_65B_02_DM==1
replace race=3 if QB_65B_04_DM==1
replace race=4 if QB_65B_03_DM==1 | QB_65B_05_DM==1 | QB_65B_97_DM==1
drop if race==.


gen income_group=.
replace income_group=1 if  QB_62_DM_NA<=22499.5
replace income_group=2 if  QB_62_DM_NA>22499.5 &  QB_62_DM_NA<=72499.5
replace income_group=3 if  QB_62_DM_NA>72499.5 &  QB_62_DM_NA<=97499.5
replace income_group=4 if  QB_62_DM_NA>97499.5
drop if income_group==.

rename zip uzip
rename QB_Weight weight
keep uzip purch age race income_group weight


//merge in county information
rename uzip zip_code
sort zip_code
merge zip_code using "zip_county_match.dta"
tab _merge
keep if _merge==3
drop _merge

// generate and rename vars.
gen year=2017

keep zip_code county purch age race income_group weight year

save "forr_2017_tmp.dta", replace


*******************************************

// append data sets together
use "forr_2006_tmp.dta", clear
append using "forr_2007_tmp.dta"
append using "forr_2010_tmp.dta"
append using "forr_2011_tmp.dta"
append using "forr_2012_tmp.dta"
append using "forr_2013_tmp.dta"
append using "forr_2014_tmp.dta"
append using "forr_2015_tmp.dta"
append using "forr_2016_tmp.dta"
append using "forr_2017_tmp.dta"

// merge in county demos
sort county year
merge m:1 county year using "county_panel.dta"
tab _merge
keep if _merge==3
drop _merge

//merge in state informatoion
sort state
merge m:1 state using "State_census_codes.dta"
keep if _merge==3
drop _merge

// rename some variables
rename state state2
rename state_abbrev state

rename census_region region
rename census_division district

//erase temp datasets
erase "forr_2006_tmp.dta"
erase "forr_2007_tmp.dta"
erase "forr_2010_tmp.dta"
erase "forr_2011_tmp.dta"
erase "forr_2012_tmp.dta"
erase "forr_2013_tmp.dta"
erase "forr_2014_tmp.dta"
erase "forr_2015_tmp.dta"
erase "forr_2016_tmp.dta"
erase "forr_2017_tmp.dta"

// save forrester data set
gen forr=1
gen obs=_n
keep obs weight purch race income_group county region forr age year state
save "forr_combine.dta", replace

************************************************************************
************************************************************************

// Third Part is to combine forrester data and comscore data (based on demographics and location), then run a regression to predict the purchase probabilty in the forrester data (based on demos and location), then use the restults to predict the purcahse probablity for each comscore household.

// transaction comscore data
use "transactions_sub_dom.dta", clear

// change mode to 1 for zappos after the aquisition
replace mode=1 if domain_name=="zappos.com" & year>=2009
egen amazon_domain_id=max(domain_id*(domain_name=="amazon.com"))
replace domain_id=amazon_domain_id if domain_name=="zappos.com" & year>=2009
replace domain_name="amazon.com" if domain_name=="zappos.com" & year>=2009

// contract data set by machine_id and year
contract machine_id year
drop _freq

// merge in the demographics of the comscore sample
sort machine_id year
merge machine_id year using "demographics.dta"
drop _merge

drop if year<2006

// merge in county for each zip code
sort zip_code
merge zip_code using "zip_county_match.dta"
tab _merge
drop _merge

// generate demographic bins to match up with forrester
gen age=.
replace age=1 if hoh_oldest_age==1 | hoh_oldest_age==2 
replace age=2 if hoh_oldest_age==3 | hoh_oldest_age==4 | hoh_oldest_age==5 | hoh_oldest_age==6 
replace age=3 if hoh_oldest_age==7 | hoh_oldest_age==8 | hoh_oldest_age==9 | hoh_oldest_age==10 
replace age=4 if hoh_oldest_age==11 
drop if age==.

gen race=6
replace race=1 if racial_background==1
replace race=2 if racial_background==2
replace race=3 if racial_background==3
replace race=4 if racial_background==5
drop if race==.

gen income_group=household_income
replace income_group=1 if income_group==1 | income_group==2 & year<=2013
replace income_group=2 if income_group==3 | income_group==4 | income_group==5 & year<=2013
replace income_group=3 if income_group==6 & year<=2013
replace income_group=4 if income_group==7 & year<=2013


replace income_group=1 if income_group==11 & year>=2014
replace income_group=2 if income_group==12 | income_group==13 | income_group==14 & year>=2014
replace income_group=3 if income_group==15 & year>=2014
replace income_group=4 if income_group>=16 & year>=2014

// merge in county demos
sort county year
merge m:1 county year using "county_panel.dta"
tab _merge
keep if _merge==3
drop _merge


// merge in state fips, district, and region codes
drop census_region
sort state
merge m:1 state using "State_census_codes.dta"
keep if _merge==3
drop _merge

// rename some variables
rename state state2
rename state_abbrev state

rename census_region region
rename census_division district

drop fips
rename county fips
sort year fips race age income_group

// variable indicating this is comscore data
gen forr=0

// append forrester data
append using "Data/Forrester/forr_combine.dta"

// create set of dummy variables for each demo bin
tab year, gen(ydum)
tab age, gen(agedum)
tab race, gen(racedum)
tab region, gen(regdum)
tab income_group, gen(incdum)
tab state, gen(statedum)

// create observation weights based on weights in forrester data
egen ave_weight=mean(weight), by(age race race income_group state forr year forr)
egen fr_weight=max(ave_weight), by(age race race income_group state year forr)

replace county=fips if county==.

//merge in urban and rural
merge m:1 county using "county_urban_rural.dta"
tab _merge
drop if _merge==2
drop _merge

// state and region IDs
egen state_id=group(state)
egen region_id=group(region)

// interact perc_urban with year dummy
forvalues i=1/12 {
gen perc_urban`i'=perc_urban*ydum`i'
}

// forreseter regression predicting the purchase probablity based on demographic bins and location variables
xi: reg purch ydum2-ydum2 ydum5-ydum12 agedum1-agedum3 racedum1-racedum3 statedum2-statedum49 incdum2-incdum4 perc_urban1-perc_urban2 perc_urban5-perc_urban12 if forr==1

predict purch_pr, xb

// generate urban bins
gen urban_rd=round(perc_urban, .1)

// since 2008 and 2009 data missing, use other data to interpolate. Assume constant growth between 2007 and 2010
egen mean_purch_pr=mean(purch_pr), by(age race race income_group state urban_rd year)
gen purch_pr_tmp07=mean_purch_pr if year==2007
gen purch_pr_tmp10=mean_purch_pr if year==2010
egen purch_pr07=max(purch_pr_tmp07), by(age race race income_group state urban_rd)
egen purch_pr10=max(purch_pr_tmp10), by(age race race income_group state urban_rd)
replace purch_pr=purch_pr07+(purch_pr10-purch_pr07)/3 if year==2008
replace purch_pr=purch_pr07+(purch_pr10-purch_pr07)*2/3 if year==2009

// fix probabilities that are outside of 0,1 range
replace purch_pr=0 if purch_pr<0
replace purch_pr=1 if purch_pr>1 & purch_pr~=.
drop if purch_pr==.


// merge in the comScore purchase probablity outside of Q1
merge m:1 year machine_id using "purch_pr_adjust.dta"
drop _freq

//create adjusted purchase probablity based on the prob they buy in the first quarter, plus the prob they didn't buy in the first quarter, but bought in Q2-Q4. This would result in the probability they bought sometime during the year
gen purch_pr_adjust=purch_pr+(1-purch_pr)*purch_pr_cs

// create averages of the purchase probabilties by years (in case need to fill in missings)
preserve
egen ave_purch_pr=mean(purch_pr), by(year)
egen ave_purch_pr_adj=mean(purch_pr_adjust), by(year)
contract year ave_purch_pr ave_purch_pr_adj
drop _freq
save "purch_pr_adjust_summary.dta", replace
restore

// create  data of just forrester purchase probablity based on demos. 
preserve
egen forr_purch_pr=mean(purch_pr_adjust), by(age race income_group state urban_rd year)
keep if forr==1
keep obs year forr_purch_pr
save "forr_purch_pr.dta", replace
restore

keep if forr==0
contract machine_id year purch_pr purch_pr_adjust
drop _freq

// save purch probablity for each set of demographics (hh) in the comscore data
save "purch_pr.dta", replace



