capture log close
set more off
clear
// Project: Nexus Tax Laws and Economies of Density in E-Commerce: A Study of Amazon’s Fulfillment Center Network
// Authors: Houde, Newberry, Seim
// Created by: Peter Newberry
// Date: 05/2022
// Description: Creates the population weights for each household in the comscore data.
// Data sets needed: ACS_*.zip: American community survey files from Census
//					 comscr_census.dta: counts of demographic groups in a geographic region in the comScore data. created in hh_expenditure.do
//					 county_panel.dta: county demographics, etc., created by authors
//					 State_census_codes.dta: state fips, region, district census codes.
// Author notes: based on author do-file "census_weights.do"

*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
//First part uses ACS files in order to caclualate the number of people in each demographic group in each county in the population. 


foreach y in 06 {
local iter="`y'"

//********************************************************************************
foreach file in B19037 B19037A B19037B B19037D {
local file2="`file'"
// Load census tabulation 
unzipfile "ACS_`y'_EST_`file'.zip", replace
insheet using "ACS_`y'_EST_`file'_with_ann.csv", clear
gen file="`file'"
drop if _n==1 | _n==2
rename v1 county_label
rename v2 fips
rename v3 county_name
reshape long v, i(county_label fips county_name) j(var ) string
gen count=real(v)
drop v
gen varid=real(var)-3
drop var
save "ACS_`iter'_EST_`file2'_with_name", replace
	
	
// Merge with demographic group names 
insheet using "ACS_`y'_EST_`file'_metadata.csv", clear
gen varid=real(subinstr(v1,"HD01_VD","",.))
drop v1
rename v2 demo_group
drop if varid==.
save "ACS_`iter'_EST_`file'_metadata", replace
joinby varid using "ACS_`y'_EST_`file'_with_name", unmatched(using)
tab _merge
drop _merge
// Create sub-group names 
split demo_group, parse(":")
replace demo_group2=trim(subinstr(demo_group2," - ","",.))
drop if demo_group2==""
save "ACS_`iter'_EST_`file2'_with_name", replace
}

//********************************************************************************
use "ACS_`iter'_EST_B19037_with_name", clear
foreach file in  B19037A B19037B B19037D {
	append using "ACS_`iter'_EST_`file'_with_name"
	}
save "ACS_`iter'_EST_B19037_merge", replace
use "../aff_filenames_new.dta", clear
joinby file using "ACS_`iter'_EST_B19037_merge", unmatched(both)
rename v2 race_group
save "ACS_`iter'_EST_B19037_merge", replace

gen main_grp=(race_group~="Total")
egen tot_main_group=sum(count), by(fips main_grp demo_group1 demo_group2)
replace tot_main_group=. if main_grp==0
egen tot_main_group2=max(tot_main_group), by(fips demo_group1 demo_group2)
replace count=count-tot_main_group2 if main_grp==0
replace count=0 if count<0

drop if count==.

// Aggregate at the ComScore level 
// Race groups 

gen race="White" if race_group==" White alone"
replace race="Asian" if race_group=="Asian alone"
replace race="Black" if race_group== "Black or African American alone"
replace race="Other" if race_group=="Total"

// Age groups 
gen age="18-24" if demo_group1=="Estimate; Householder under 25 years"
replace age="25-44" if demo_group1=="Estimate; Householder 25 to 44 years"
replace age="45-64" if demo_group1=="Estimate; Householder 45 to 64 years"
replace age="65 and over" if demo_group1=="Estimate; Householder 65 years and over"

// Income groups 
replace demo_group2=subinstr(demo_group2,"$","",.)
replace demo_group2=subinstr(demo_group2,",","",.)
split demo_group2, parse(" to ")
gen income_low=real(demo_group21)
gen income_high=real(demo_group22)
replace income_high=10000 if demo_group21=="Less than 10000"
replace income_low=200000 if demo_group2=="200000 or more"
replace income_high=100000000000 if income_high==.
replace income_low=0 if income_low==.

gen income_low_string="Less than" if income_low<25000
replace income_low_string="25k" if income_low>=25000 & income_low<75000
replace income_low_string="75k" if income_low>=75000 & income_low<100000
replace income_low_string="100k" if income_low>=100000 

gen income_high_string=" 25k" if income_high<25000
replace income_high_string="-74.999k" if income_high>=25000 & income_high<75000
replace income_high_string="-99.999k" if income_high>=75000 & income_high<100000
replace income_high_string="+" if income_low>=100000 
gen income_group=income_low_string+income_high_string

//********************************************************************************
// Collapse: Demographic group level 
collapse (sum) count, by(income_group age race fips county_name county_label)
bysort county_label : egen county_population=sum(count)
gen share=count/county_population
save "County_population_weight1_20`iter'", replace


//
// Income mid group 
gen income_mid=15 if income_group=="Less than 15k"
replace income_mid=20 if income_group=="15k-24.999k"
replace income_mid=30 if income_group=="25k-34.999k"
replace income_mid=43 if income_group=="35k-49.999k"
replace income_mid=63 if income_group=="50k-74.999k"
replace income_mid=88 if income_group=="75k-99.999k"
replace income_mid=150 if income_group=="100k+"



gen income_mid=20 if income_group=="Less than 25k"
replace income_mid=50 if income_group=="25k-74.999k"
replace income_mid=88 if income_group=="75k-99.999k"
replace income_mid=150 if income_group=="100k+"


// Age mid group 
split age, parse("-")
gen age_mid=(real(age1)+real(age2))/2
replace age_mid=65 if age_mid==.
drop age1 age2

// Race 
gen White_dummy=race=="White"
gen Asian_dummy=race=="Asian"
gen Black_dummy=race=="Black"
gen Other_dummy=race=="Other"

// Median demographics 
foreach var in age income {
	sort fips `var'_mid
	gen cumu_share=share if fips!=fips[_n-1]
	replace cumu_share=cumu_share[_n-1]+share if fips==fips[_n-1]
	gen median_`var'=`var'_mid if (cumu_share>=0.5 & cumu_share[_n-1]<0.5) & fips==fips[_n-1]
	bysort fips: egen m=mean(median_`var')
	replace median_`var'=m
	drop m
	drop cumu_share
	}

// Fraction of race groups 
foreach var in White Asian Black Other {
	gen w`var'=share*`var'_dummy
	bysort  fips: egen `var'_share=sum(w`var')
	drop w`var'
	}

// Numerical FIPS 
rename fips fips_string
gen fips=real(fips_string)
gen year=20`iter'
save "County_population_weight1_20`iter'", replace
foreach file in B19037 B19037A B19037B B19037D {
erase "ACS_06_EST_`file'.txt"
erase "ACS_06_EST_`file'_with_name.dta"
erase "ACS_06_EST_`file'_with_ann.csv"
erase "ACS_06_EST_`file'_metadata.dta"
erase "ACS_06_EST_`file'_metadata.csv"
}
erase "ACS_06_EST_B19037_merge.dta"
}



//
// AFTER 2006 DIFFERENT FORMAT OF FILENAMES 


foreach y in 07 08 09 10 11 12 13 14 15 16{

local iter="`y'"
//********************************************************************************
foreach file in B19037 B19037A B19037B B19037D {
local file2="`file'"
// Load census tabulation 
unzipfile "ACS_`y'_1YR_`file'.zip", replace
insheet using "ACS_`y'_1YR_`file'_with_ann.csv", clear
gen file="`file'"
drop if _n==1 | _n==2
rename v1 county_label
rename v2 fips
rename v3 county_name
reshape long v, i(county_label fips county_name) j(var ) string
gen count=real(v)
drop v
gen varid=real(var)-3
drop var
save "ACS_`iter'_1YR_`file2'_with_name", replace
	
	
// Merge with demographic group names 
insheet using "ACS_`y'_1YR_`file'_metadata.csv", clear
gen varid=real(subinstr(v1,"HD01_VD","",.))
drop v1
rename v2 demo_group
drop if varid==.
save "ACS_`iter'_1YR_`file'_metadata", replace
joinby varid using "ACS_`y'_1YR_`file'_with_name", unmatched(using)
tab _merge
drop _merge
// Create sub-group names 
split demo_group, parse(":")
replace demo_group2=trim(subinstr(demo_group2," - ","",.))
drop if demo_group2==""
save "ACS_`iter'_1YR_`file2'_with_name", replace
}

//********************************************************************************
use "ACS_`iter'_1YR_B19037_with_name", clear
foreach file in  B19037A B19037B B19037D {
	append using "ACS_`iter'_1YR_`file'_with_name"
	}
save "ACS_`iter'_1YR_B19037_merge", replace
use "../aff_filenames_new.dta", clear
joinby file using "ACS_`iter'_1YR_B19037_merge", unmatched(both)
rename v2 race_group
save "ACS_`iter'_1YR_B19037_merge", replace

gen main_grp=(race_group~="Total")
egen tot_main_group=sum(count), by(fips main_grp demo_group1 demo_group2)
replace tot_main_group=. if main_grp==0
egen tot_main_group2=max(tot_main_group), by(fips demo_group1 demo_group2)
replace count=count-tot_main_group2 if main_grp==0
replace count=0 if count<0
*drop if count==0
drop if count==.

// Aggregate at the ComScore level 
// Race groups 

gen race="White" if race_group==" White alone"
replace race="Asian" if race_group=="Asian alone"
replace race="Black" if race_group== "Black or African American alone"
replace race="Other" if race_group=="Total"

// Age groups 
gen age="18-24" if demo_group1=="Estimate; Householder under 25 years"
replace age="25-44" if demo_group1=="Estimate; Householder 25 to 44 years"
replace age="45-64" if demo_group1=="Estimate; Householder 45 to 64 years"
replace age="65 and over" if demo_group1=="Estimate; Householder 65 years and over"

// Income groups 
replace demo_group2=subinstr(demo_group2,"$","",.)
replace demo_group2=subinstr(demo_group2,",","",.)
split demo_group2, parse(" to ")
gen income_low=real(demo_group21)
gen income_high=real(demo_group22)
replace income_high=10000 if demo_group21=="Less than 10000"
replace income_low=200000 if demo_group2=="200000 or more"
replace income_high=100000000000 if income_high==.
replace income_low=0 if income_low==.

gen income_low_string="Less than" if income_low<25000
replace income_low_string="25k" if income_low>=25000 & income_low<75000
replace income_low_string="75k" if income_low>=75000 & income_low<100000
replace income_low_string="100k" if income_low>=100000 

gen income_high_string=" 25k" if income_high<25000
replace income_high_string="-74.999k" if income_high>=25000 & income_high<75000
replace income_high_string="-99.999k" if income_high>=75000 & income_high<100000
replace income_high_string="+" if income_low>=100000 
gen income_group=income_low_string+income_high_string

//********************************************************************************
// Collapse: Demographic group level 
collapse (sum) count, by(income_group age race fips county_name county_label)
bysort county_label : egen county_population=sum(count)
gen share=count/county_population
save "County_population_weight1_20`iter'", replace


//
// Income mid group 
gen income_mid=15 if income_group=="Less than 15k"
replace income_mid=20 if income_group=="15k-24.999k"
replace income_mid=30 if income_group=="25k-34.999k"
replace income_mid=43 if income_group=="35k-49.999k"
replace income_mid=63 if income_group=="50k-74.999k"
replace income_mid=88 if income_group=="75k-99.999k"
replace income_mid=150 if income_group=="100k+"


gen income_mid=20 if income_group=="Less than 25k"
replace income_mid=50 if income_group=="25k-74.999k"
replace income_mid=88 if income_group=="75k-99.999k"
replace income_mid=150 if income_group=="100k+"



// Age mid group 
split age, parse("-")
gen age_mid=(real(age1)+real(age2))/2
replace age_mid=65 if age_mid==.
drop age1 age2

// Race 
gen White_dummy=race=="White"
gen Asian_dummy=race=="Asian"
gen Black_dummy=race=="Black"
gen Other_dummy=race=="Other"

// Median demographics 
foreach var in age income {
	sort fips `var'_mid
	gen cumu_share=share if fips!=fips[_n-1]
	replace cumu_share=cumu_share[_n-1]+share if fips==fips[_n-1]
	gen median_`var'=`var'_mid if (cumu_share>=0.5 & cumu_share[_n-1]<0.5) & fips==fips[_n-1]
	bysort fips: egen m=mean(median_`var')
	replace median_`var'=m
	drop m
	drop cumu_share
	}

// Fraction of race groups 
foreach var in White Asian Black Other {
	gen w`var'=share*`var'_dummy
	bysort  fips: egen `var'_share=sum(w`var')
	drop w`var'
	}

// Numerical FIPS 
rename fips fips_string
gen fips=real(fips_string)
gen year=20`iter'
save "County_population_weight1_20`iter'", replace
foreach file in B19037 B19037A B19037B B19037D {
erase "ACS_`iter'_1YR_`file'.txt"
erase "ACS_`iter'_1YR_`file'_with_name.dta"
erase "ACS_`iter'_1YR_`file'_with_ann.csv"
erase "ACS_`iter'_1YR_`file'_metadata.dta"
erase "ACS_`iter'_1YR_`file'_metadata.csv"
}
erase "ACS_`iter'_1YR_B19037_merge.dta"
}


use "County_population_weight1_2006", clear
foreach file in 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 {
append using "County_population_weight1_`file'"
}
save "County_population_weight1", replace


//
// USING 5-YEAR ACS


foreach y in 09 10 11 12 13 {

local iter="`y'"

//********************************************************************************
foreach file in B19037 B19037A B19037B B19037D {
local file2="`file'"
// Load census tabulation 
unzipfile "ACS_`y'_5YR_`file'.zip", replace
insheet using "ACS_`y'_5YR_`file'_with_ann.csv", clear names
gen file="`file'"
drop hd02*
drop if _n==1
rename geoid county_label
rename geoid2 fips
rename geodisplaylabel county_name
reshape long hd01_vd, i(county_label fips county_name) j(var ) string
gen count=real(hd01_vd)
drop hd01_vd
gen varid=real(var)
drop var
save "ACS_`iter'_5YR_`file2'_with_name", replace

	
// Merge with demographic group names 
insheet using "ACS_`y'_5YR_`file'_metadata.csv", clear
gen varid=real(subinstr(v1,"HD01_VD","",.))
drop v1
rename v2 demo_group
drop if varid==.
save "ACS_`iter'_5YR_`file'_metadata", replace
joinby varid using "ACS_`y'_5YR_`file'_with_name", unmatched(using)
tab _merge
drop _merge
// Create sub-group names 
split demo_group, parse(":")
replace demo_group2=trim(subinstr(demo_group2," - ","",.))
drop if demo_group2==""
save "ACS_`iter'_5YR_`file2'_with_name", replace
}

//********************************************************************************
use "ACS_`iter'_5YR_B19037_with_name", clear
foreach file in  B19037A B19037B B19037D {
	append using "ACS_`iter'_5YR_`file'_with_name"
	}
save "ACS_`iter'_5YR_B19037_merge", replace
use "../aff_filenames_new.dta", clear
joinby file using "ACS_`iter'_5YR_B19037_merge", unmatched(both)
rename v2 race_group
save "ACS_`iter'_5YR_B19037_merge", replace

gen main_grp=(race_group~="Total")
egen tot_main_group=sum(count), by(fips main_grp demo_group1 demo_group2)
replace tot_main_group=. if main_grp==0
egen tot_main_group2=max(tot_main_group), by(fips demo_group1 demo_group2)
replace count=count-tot_main_group2 if main_grp==0
replace count=0 if count<0
*drop if count==0
drop if count==.

// Aggregate at the ComScore level 
// Race groups 

gen race="White" if race_group==" White alone"
replace race="Asian" if race_group=="Asian alone"
replace race="Black" if race_group== "Black or African American alone"
replace race="Other" if race_group=="Total"

// Age groups 
gen age="18-24" if demo_group1=="Estimate; Householder under 25 years"
replace age="25-44" if demo_group1=="Estimate; Householder 25 to 44 years"
replace age="45-64" if demo_group1=="Estimate; Householder 45 to 64 years"
replace age="65 and over" if demo_group1=="Estimate; Householder 65 years and over"

// Income groups 
replace demo_group2=subinstr(demo_group2,"$","",.)
replace demo_group2=subinstr(demo_group2,",","",.)
split demo_group2, parse(" to ")
gen income_low=real(demo_group21)
gen income_high=real(demo_group22)
replace income_high=10000 if demo_group21=="Less than 10000"
replace income_low=200000 if demo_group2=="200000 or more"
replace income_high=100000000000 if income_high==.
replace income_low=0 if income_low==.

gen income_low_string="Less than" if income_low<25000
replace income_low_string="25k" if income_low>=25000 & income_low<75000
replace income_low_string="75k" if income_low>=75000 & income_low<100000
replace income_low_string="100k" if income_low>=100000 

gen income_high_string=" 25k" if income_high<25000
replace income_high_string="-74.999k" if income_high>=25000 & income_high<75000
replace income_high_string="-99.999k" if income_high>=75000 & income_high<100000
replace income_high_string="+" if income_low>=100000 
gen income_group=income_low_string+income_high_string

//********************************************************************************
// Collapse: Demographic group level 
collapse (sum) count, by(income_group age race fips county_name county_label)
bysort county_label : egen county_population=sum(count)
gen share=count/county_population
save "County_population_weight5_20`iter'", replace


//
// Income mid group 
gen income_mid=25 if income_group=="Less than 25k"
replace income_mid=30 if income_group=="25k-34.999k"
replace income_mid=43 if income_group=="35k-49.999k"
replace income_mid=63 if income_group=="50k-74.999k"
replace income_mid=88 if income_group=="75k-99.999k"
replace income_mid=150 if income_group=="100k+"


gen income_mid=20 if income_group=="Less than 25k"
replace income_mid=50 if income_group=="25k-74.999k"
replace income_mid=88 if income_group=="75k-99.999k"
replace income_mid=150 if income_group=="100k+"



// Age mid group 
split age, parse("-")
gen age_mid=(real(age1)+real(age2))/2
replace age_mid=65 if age_mid==.
drop age1 age2

// Race 
gen White_dummy=race=="White"
gen Asian_dummy=race=="Asian"
gen Black_dummy=race=="Black"
gen Other_dummy=race=="Other"

// Median demographics 
foreach var in age income {
	sort fips `var'_mid
	gen cumu_share=share if fips!=fips[_n-1]
	replace cumu_share=cumu_share[_n-1]+share if fips==fips[_n-1]
	gen median_`var'=`var'_mid if (cumu_share>=0.5 & cumu_share[_n-1]<0.5) & fips==fips[_n-1]
	bysort fips: egen m=mean(median_`var')
	replace median_`var'=m
	drop m
	drop cumu_share
	}

// Fraction of race groups 
foreach var in White Asian Black Other {
	gen w`var'=share*`var'_dummy
	bysort  fips: egen `var'_share=sum(w`var')
	drop w`var'
	}

// Numerical FIPS 
rename fips fips_string
gen fips=real(fips_string)
gen year=20`iter'
save "County_population_weight5_20`iter'", replace
foreach file in B19037 B19037A B19037B B19037D {
erase "ACS_`iter'_5YR_`file'.txt"
erase "ACS_`iter'_5YR_`file'_with_name.dta"
erase "ACS_`iter'_5YR_`file'_with_ann.csv"
erase "ACS_`iter'_5YR_`file'_metadata.dta"
erase "ACS_`iter'_5YR_`file'_metadata.csv"
}
erase "ACS_`iter'_5YR_B19037_merge.dta"
}



// need income groups to match the comscore data 
foreach y in  14 15 {

local iter="`y'"

//********************************************************************************
foreach file in B19037 B19037A B19037B B19037D {
local file2="`file'"
// Load census tabulation 
unzipfile "ACS_`y'_5YR_`file'.zip", replace
insheet using "ACS_`y'_5YR_`file'_with_ann.csv", clear names
gen file="`file'"
drop hd02*
drop if _n==1
rename geoid county_label
rename geoid2 fips
rename geodisplaylabel county_name
reshape long hd01_vd, i(county_label fips county_name) j(var ) string
gen count=real(hd01_vd)
drop hd01_vd
gen varid=real(var)
drop var
save "ACS_`iter'_5YR_`file2'_with_name", replace

	
// Merge with demographic group names 
insheet using "ACS_`y'_5YR_`file'_metadata.csv", clear
gen varid=real(subinstr(v1,"HD01_VD","",.))
drop v1
rename v2 demo_group
drop if varid==.
save "ACS_`iter'_5YR_`file'_metadata", replace
joinby varid using "ACS_`y'_5YR_`file'_with_name", unmatched(using)
tab _merge
drop _merge
// Create sub-group names 
split demo_group, parse(":")
replace demo_group2=trim(subinstr(demo_group2," - ","",.))
drop if demo_group2==""
save "ACS_`iter'_5YR_`file2'_with_name", replace
}

//********************************************************************************
use "ACS_`iter'_5YR_B19037_with_name", clear
foreach file in  B19037A B19037B B19037D {
	append using "ACS_`iter'_5YR_`file'_with_name"
	}
save "ACS_`iter'_5YR_B19037_merge", replace
use "../aff_filenames_new.dta", clear
joinby file using "ACS_`iter'_5YR_B19037_merge", unmatched(both)
rename v2 race_group
save "ACS_`iter'_5YR_B19037_merge", replace

gen main_grp=(race_group~="Total")
egen tot_main_group=sum(count), by(fips main_grp demo_group1 demo_group2)
replace tot_main_group=. if main_grp==0
egen tot_main_group2=max(tot_main_group), by(fips demo_group1 demo_group2)
replace count=count-tot_main_group2 if main_grp==0
replace count=0 if count<0
*drop if count==0
drop if count==.

// Aggregate at the ComScore level 
// Race groups 

gen race="White" if race_group==" White alone"
replace race="Asian" if race_group=="Asian alone"
replace race="Black" if race_group== "Black or African American alone"
replace race="Other" if race_group=="Total"

// Age groups 
gen age="18-24" if demo_group1=="Estimate; Householder under 25 years"
replace age="25-44" if demo_group1=="Estimate; Householder 25 to 44 years"
replace age="45-64" if demo_group1=="Estimate; Householder 45 to 64 years"
replace age="65 and over" if demo_group1=="Estimate; Householder 65 years and over"

// Income groups 
replace demo_group2=subinstr(demo_group2,"$","",.)
replace demo_group2=subinstr(demo_group2,",","",.)
split demo_group2, parse(" to ")
gen income_low=real(demo_group21)
gen income_high=real(demo_group22)

replace income_high=10000 if demo_group21=="Less than 10000"
replace income_low=200000 if demo_group2=="200000 or more"
replace income_high=100000000000 if income_high==.
replace income_low=0 if income_low==.

gen income_low_string="Less than" if income_low<25000
replace income_low_string="25k" if income_low>=25000 & income_low<75000
replace income_low_string="75k" if income_low>=75000 & income_low<100000
replace income_low_string="100k" if income_low>=100000 

gen income_high_string=" 25k" if income_high<25000
replace income_high_string="-74.999k" if income_high>=25000 & income_high<75000
replace income_high_string="-99.999k" if income_high>=75000 & income_high<100000
replace income_high_string="+" if income_low>=100000 
gen income_group=income_low_string+income_high_string

//********************************************************************************
// Collapse: Demographic group level 
collapse (sum) count, by(income_group age race fips county_name county_label)
bysort county_label : egen county_population=sum(count)
gen share=count/county_population
save "County_population_weight5_20`iter'", replace


//
// Income mid group 
gen income_mid=25 if income_group=="Less than 25k"
replace income_mid=32.5 if income_group=="25k-39.999k"
replace income_mid=50 if income_group=="40k-59.999k"
replace income_mid=67.5 if income_group=="60k-74.999k"
replace income_mid=87.5 if income_group=="75k-99.999k"
replace income_mid=125 if income_group=="100k-149.999k"
replace income_mid=175 if income_group=="150k-199.999k"
replace income_mid=250 if income_group=="200k+"


gen income_mid=20 if income_group=="Less than 25k"
replace income_mid=50 if income_group=="25k-74.999k"
replace income_mid=88 if income_group=="75k-99.999k"
replace income_mid=150 if income_group=="100k+"

// Age mid group 
split age, parse("-")
gen age_mid=(real(age1)+real(age2))/2
replace age_mid=65 if age_mid==.
drop age1 age2

// Race 
gen White_dummy=race=="White"
gen Asian_dummy=race=="Asian"
gen Black_dummy=race=="Black"
gen Other_dummy=race=="Other"

// Median demographics 
foreach var in age income {
	sort fips `var'_mid
	gen cumu_share=share if fips!=fips[_n-1]
	replace cumu_share=cumu_share[_n-1]+share if fips==fips[_n-1]
	gen median_`var'=`var'_mid if (cumu_share>=0.5 & cumu_share[_n-1]<0.5) & fips==fips[_n-1]
	bysort fips: egen m=mean(median_`var')
	replace median_`var'=m
	drop m
	drop cumu_share
	}

// Fraction of race groups 
foreach var in White Asian Black Other {
	gen w`var'=share*`var'_dummy
	bysort  fips: egen `var'_share=sum(w`var')
	drop w`var'
	}

// Numerical FIPS 
rename fips fips_string
gen fips=real(fips_string)
gen year=20`iter'
save "County_population_weight5_20`iter'", replace
foreach file in B19037 B19037A B19037B B19037D {
erase "ACS_`iter'_5YR_`file'.txt"
erase "ACS_`iter'_5YR_`file'_with_name.dta"
erase "ACS_`iter'_5YR_`file'_with_ann.csv"
erase "ACS_`iter'_5YR_`file'_metadata.dta"
erase "ACS_`iter'_5YR_`file'_metadata.csv"
}
erase "ACS_`iter'_5YR_B19037_merge.dta"
}


use "County_population_weight5_2009", clear
keep county_label fips_string county_name race age income_group count share fips year county_population
replace count=.
replace share=.
replace county_population=.
replace year=2006
save "County_population_weight5_2006", replace

use "County_population_weight5_2009", clear
keep county_label fips_string county_name race age income_group count share fips year county_population
replace count=.
replace share=.
replace county_population=.
replace year=2007
save "County_population_weight5_2007", replace

use "County_population_weight5_2009", clear
keep county_label fips_string county_name race age income_group count share fips year county_population
replace count=.
replace share=.
replace county_population=.
replace year=2008
save "County_population_weight5_2008", replace

use "County_population_weight5_2014", clear
keep county_label fips_string county_name race age income_group count share fips year county_population
replace count=.
replace share=.
replace county_population=.
replace year=2016
save "County_population_weight5_2016", replace


use "County_population_weight5_2014", clear
keep county_label fips_string county_name race age income_group count share fips year county_population
replace count=.
replace share=.
replace county_population=.
replace year=2017
save "County_population_weight5_2017", replace

use "County_population_weight5_2009", clear
foreach file in 2006 2007 2008 2010 2011 2012 2013 2014 2015 2016 2017 {
append using "County_population_weight5_`file'"
}
save "County_population_weight5", replace



//
// USE 2000 CENSUS TO GET GROWTH
//********************************************************************************
foreach file in PCT072A PCT072B PCT072C PCT072D PCT072E PCT072F PCT072G PCT072H PCT072I {
	// Load census tabulation 
	insheet using DEC_00_SF3_`file'_with_ann.csv, clear
	gen file="`file'"
	drop if _n==1 | _n==2
	rename v1 county_label
	rename v2 fips
	rename v3 county_name
	reshape long v, i(county_label fips county_name) j(var ) string
	gen count=real(v)
	drop v
	gen varid=real(var)-3
	drop var
	save DEC_00_SF3_`file'_with_name, replace
	// Merge with demographic group names 
	insheet using DEC_00_SF3_`file'_metadata.csv, clear
	gen varid=real(subinstr(v1,"VD","",.))
	drop v1
	rename v2 demo_group
	drop if varid==.
	save DEC_00_SF3_`file'_metadata, replace
	joinby varid using DEC_00_SF3_`file'_with_name, unmatched(using)
	tab _merge
	drop _merge
	// Create sub-group names 
	split demo_group, parse(":")
	replace demo_group2=trim(subinstr(demo_group2," - ","",.))
	drop if demo_group2==""
	save DEC_00_SF3_`file'_with_name, replace
	}


//********************************************************************************
use DEC_00_SF3_PCT072A_with_name, clear
foreach file in  PCT072B PCT072C PCT072D PCT072E PCT072F PCT072G PCT072H PCT072I {
	append using DEC_00_SF3_`file'_with_name
	}
save DECC_00_PCT072_merge, replace
insheet using ../aff_filenames.csv, clear
rename v1 file
replace file=trim(file)
rename v2 race_group
joinby file using DECC_00_PCT072_merge, unmatched(both)
save DECC_00_PCT072_merge, replace

// Aggregate at the ComScore level 
// Race groups 
gen race="White" if race_group=="White alone"
drop if race_group=="White alone, not Hispanic or Latino" | race_group=="Hispanic or Latino"
replace race="Asian" if race_group=="Asian alone"
replace race="Black" if race_group== "Black or African American alone"
replace race="Other" if race==""

// Age groups 
gen age="18-24" if demo_group1=="Householder under 25 years"
replace age="25-44" if demo_group1=="Householder 25 to 34 years" | demo_group1=="Householder 35 to 44 years"
replace age="45-64" if demo_group1=="Householder 45 to 54 years" | demo_group1=="Householder 55 to 64 years"
replace age="65 and over" if demo_group1=="Householder 65 to 74 years" | demo_group1=="Householder 75 years and over"

// Income groups 
replace demo_group2=subinstr(demo_group2,"$","",.)
replace demo_group2=subinstr(demo_group2,",","",.)
split demo_group2, parse(" to ")
gen income_low=real(demo_group21)
gen income_high=real(demo_group22)
replace income_high=10000 if demo_group21=="Less than 10000"
replace income_low=200000 if demo_group2=="200000 or more"
replace income_high=100000000000 if income_high==.
replace income_low=0 if income_low==.

gen income_low_string="Less than" if income_low<25000
replace income_low_string="25k" if income_low>=25000 & income_low<75000
replace income_low_string="75k" if income_low>=75000 & income_low<100000
replace income_low_string="100k" if income_low>=100000 

gen income_high_string=" 25k" if income_high<25000
replace income_high_string="-74.999k" if income_high>=25000 & income_high<75000
replace income_high_string="-99.999k" if income_high>=75000 & income_high<100000
replace income_high_string="+" if income_low>=100000 
gen income_group=income_low_string+income_high_string

//********************************************************************************
// Collapse: Demographic group level 
collapse (sum) count, by(income_group age race fips county_name county_label)
bysort county_label : egen county_population=sum(count)
gen share=count/county_population
save County_population_weight_2010, replace


//
// Income mid group 
gen income_mid=25 if income_group=="Less than 25k"
replace income_mid=30 if income_group=="25k-34.999k"
replace income_mid=43 if income_group=="35k-49.999k"
replace income_mid=63 if income_group=="50k-74.999k"
replace income_mid=88 if income_group=="75k-99.999k"
replace income_mid=150 if income_group=="100k+"


gen income_mid=20 if income_group=="Less than 25k"
replace income_mid=50 if income_group=="25k-74.999k"
replace income_mid=88 if income_group=="75k-99.999k"
replace income_mid=150 if income_group=="100k+"



// Age mid group 
split age, parse("-")
gen age_mid=(real(age1)+real(age2))/2
replace age_mid=65 if age_mid==.
drop age1 age2

// Race 
gen White_dummy=race=="White"
gen Asian_dummy=race=="Asian"
gen Black_dummy=race=="Black"
gen Other_dummy=race=="Other"

// Median demographics 
foreach var in age income {
	sort fips `var'_mid
	gen cumu_share=share if fips!=fips[_n-1]
	replace cumu_share=cumu_share[_n-1]+share if fips==fips[_n-1]
	gen median_`var'=`var'_mid if (cumu_share>=0.5 & cumu_share[_n-1]<0.5) & fips==fips[_n-1]
	bysort fips: egen m=mean(median_`var')
	replace median_`var'=m
	drop m
	drop cumu_share
	}

// Fraction of race groups 
foreach var in White Asian Black Other {
	gen w`var'=share*`var'_dummy
	bysort  fips: egen `var'_share=sum(w`var')
	drop w`var'
	}

// Numerical FIPS 
rename fips fips_string
gen fips=real(fips_string)

rename share share00
sort fips
save "County_population_weight_2000", replace


//
//MERGE THE WEIGHTS OF 2000 CENSUS WITH 2009-2015 ACS

use "County_population_weight5", clear
append using "County_population_weight_2000"
replace year=2000 if share00~=.
gen count00_tmp=count if year==2000
egen count00=max(count00_tmp), by(fips race age income_group)
gen growth_tmp=(count-count00)/9 if year==2009


egen growth=max(growth_tmp), by(fips race age income_group)
egen pop_group=group(fips race age income_group)
tsset pop_group year
replace growth=0 if growth==.


gen count_tmp=F.count-growth
replace count=count_tmp if year==2008
drop count_tmp
gen count_tmp=F.count-growth
replace count=count_tmp if year==2007
drop count_tmp
gen count_tmp=F.count-growth
replace count=count_tmp if year==2006
drop count_tmp
drop growth growth_tmp share00 count00_tmp count00
drop if year==2000


gen growth_tmp=(count-L.count) if year==2015
egen growth=max(growth_tmp), by(fips race age income_group)
replace growth=0 if growth==.
gen count_tmp=L.count+growth
replace count=count_tmp if year==2016
drop count_tmp
gen count_tmp=L.count+growth
replace count=count_tmp if year==2017
drop count_tmp
drop growth growth_tmp 
replace count=round(count)
replace count=0 if count<0
egen tot_pop=sum(count), by(fips year)
replace county_population=tot_pop if county_population==.
gen share_tmp=count/county_population
replace share=share_tmp if share==.


// Income mid group 
//
drop income_mid
gen income_mid=25 if income_group=="Less than 25k"
replace income_mid=30 if income_group=="25k-34.999k"
replace income_mid=43 if income_group=="35k-49.999k"
replace income_mid=63 if income_group=="50k-74.999k"
replace income_mid=88 if income_group=="75k-99.999k"
replace income_mid=150 if income_group=="100k+"

drop income_mid
gen income_mid=20 if income_group=="Less than 25k"
replace income_mid=50 if income_group=="25k-74.999k"
replace income_mid=88 if income_group=="75k-99.999k"
replace income_mid=150 if income_group=="100k+"


//
// Income mid group 
replace income_mid=25 if income_group=="Less than 25k"
replace income_mid=32.5 if income_group=="25k-39.999k"
replace income_mid=50 if income_group=="40k-59.999k"
replace income_mid=67.5 if income_group=="60k-74.999k"
replace income_mid=87.5 if income_group=="75k-99.999k"
replace income_mid=125 if income_group=="100k-149.999k"
replace income_mid=175 if income_group=="150k-199.999k"
replace income_mid=250 if income_group=="200k+"




// Age mid group 
drop age_mid
split age, parse("-")
gen age_mid=(real(age1)+real(age2))/2
replace age_mid=65 if age_mid==.
drop age1 age2

// Race 
drop White_dummy
drop Asian_dummy
drop Black_dummy
drop Other_dummy

gen White_dummy=race=="White"
gen Asian_dummy=race=="Asian"
gen Black_dummy=race=="Black"
gen Other_dummy=race=="Other"

drop median_*
// Median demographics 
foreach var in age income {
	sort year fips `var'_mid
	gen cumu_share=share if fips!=fips[_n-1]
	replace cumu_share=cumu_share[_n-1]+share if fips==fips[_n-1]
	gen median_`var'=`var'_mid if (cumu_share>=0.5 & cumu_share[_n-1]<0.5) & fips==fips[_n-1]
	bysort fips year: egen m=mean(median_`var')
	replace median_`var'=m
	drop m
	drop cumu_share
	}

drop *_share
// Fraction of race groups 
foreach var in White Asian Black Other {
	gen w`var'=share*`var'_dummy
	bysort  fips year: egen `var'_share=sum(w`var')
	drop w`var'
	}



sort fips race age income_group
save "county_population_weight.dta", replace

*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
//second part merges with the comscore census and creates the weights.

// Merge with comscr_census 
use "county_population_weight.dta", clear

// redefine demo groups
egen age2=group(age)
gen race2=.
replace race2=1 if race=="White"
replace race2=2 if race=="Black"
replace race2=3 if race=="Asian"
replace race2=4 if race=="Other"


gen income_group2=.
replace income_group2=1 if income_group=="Less than 25k"
replace income_group2=2 if income_group=="25k-74.999k"
replace income_group2=3 if income_group=="75k-99.999k" 
replace income_group2=4 if income_group=="100k+"



drop age race income_group
rename age2 age
rename race2 race
rename income_group2 income_group


sort  year fips race age income_group
merge year fips race age income_group using "comscr_census.dta"
tab _merge
drop _merge

rename group_tot group_tot2

replace group_tot2=0 if count==0 & group_tot2>0 & group_tot2~=.

rename group_tot2 comscore_hh

keep fips race age income_group year count comscore_hh* median_age median_income White_share Asian_share Black_share Other_share
rename fips county

// merge in county information
sort county year
merge m:1 county year using "county_panel.dta"
tab _merge
keep if _merge==3
drop _merge


// merge in state codes, census region and district
drop census_region
sort state
merge m:1 state using "State_census_codes.dta"
keep if _merge==3
drop _merge

rename state state2
rename state_abbrev state

rename census_region region
rename census_division district


egen tot_hh_us_true=sum(count), by(year)

//COUNTY LEVEL WEIGHTS WITHOUT FORRESTER WEIGHTS
egen n_county_group=sum(count), by(county year race age income_group)
egen n_county=sum(count), by(county year)

egen cs_county_group=sum(comscore_hh), by(county year race age income_group)
gen w_i_county=n_county_group/cs_county_group
egen cs_n_county=sum(w_i_county*comscore_hh), by(county year)
gen w_i_adj_county=n_county/cs_n_county
gen weight_county1=w_i_county*w_i_adj_county

egen tot_hh_us_county=sum(weight_county1*comscore_hh), by(year)


// adjustment for the different number of households that we end up using in the anaylsis (that slightly differs from the ACS data)

replace weight_county1=weight_county1*(nb_hh/n_county)

sort county race age income_group year

save "comscore_population_weight.dta", replace
