capture log close
set more off
clear
// Project: Nexus Tax Laws and Economies of Density in E-Commerce: A Study of Amazon’s Fulfillment Center Network
// Authors: Houde, Newberry, Seim
// Created by: Peter Newberry
// Date: 05/2022
// Description: Creates the average prices and prices dispersion using the comscore data.
// Data sets needed: transactions_sub_dom.dta: comScore transaction level data (proprietary)
//					 demographics.dta: raw demographics file from comScore (proprietary)
//					 zip_county_match.dta: matches zip codes with the primary county they are in.
//					 county_panel.dta: county demographics, etc., created by authors
//					 State_census_codes.dta: state fips, region, district census codes.
//					 Panel_county_tax_dist.dta: has county level tax information as well as information on distances to FCs and SCS. The tax information is propreitary. Souces is TDS (tax data systems).It also has whether or not transacitons in the year/mode are taxable. 
//					 comscore_population_weight.dta: population weights used to aggregate data. calculated in population_weights.do						
// Author notes: based on author do-file "ave_county_price.do"

*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
*****************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************

// comscore transaciton level data
use "transactions_sub_dom.dta", clear

// change zappos to mode 1 after aquisition
replace mode=1 if domain_name=="zappos.com" & year>=2009
egen amazon_domain_id=max(domain_id*(domain_name=="amazon.com"))
replace domain_id=amazon_domain_id if domain_name=="zappos.com" & year>=2009
replace domain_name="amazon.com" if domain_name=="zappos.com" & year>=2009

//merge in comscore demo graphic information
sort machine_id year
merge machine_id year using "demographics.dta"
tab _merge
keep if _merge==3

// drop 2004 and 2005
keep if year>=2006
drop _merge
drop if mode==.

// merge in the zip county match
sort zip_code
merge zip_code using "zip_county_match.dta"
tab _merge
keep if _merge==3
drop _merge

// merge in county demos
sort county year
merge m:1 county year using "county_panel.dta"
tab _merge
keep if _merge==3
drop _merge

// merge in state fips as well as region and district number
drop census_region
sort state
merge m:1 state using "State_census_codes.dta"
keep if _merge==3
drop _merge


//rename variabes
rename state state2
rename state_abbrev state

rename census_region region
rename census_division district

//drop HI and AK
drop if state=="AK" | state=="HI"


//merge in tax rates
merge m:1 county_code year using "Panel_county_tax_dist.dta"
tab _merge
keep if _merge==3
drop _merge

//generate applied tax rates for each mode
gen tax2=tax
replace tax2=amazon_tax if mode==1
replace tax2=tax if mode==2
replace tax2=0 if mode==3
replace tax=tax2 
drop tax2

// generate the basket total across all products within a basket
egen tot_price_basket=sum(prod_totprice), by(machine_id site_session_id domain_id basket_tot year mode)

// generate the percentage of the basket total for each product
gen perc_basket=prod_totprice/tot_price_basket


// try to back out shipping charges by subtracting taxes and prices of products from the basket tot variable in comscore
gen ship=basket_tot-tot_price_basket - tax*tot_price_basket 
replace ship=round(ship,.01)

// create a shipping charge per item
egen ship_per=mean(ship), by(machine_id site_session_id domain_id basket_tot year mode)
drop tot_price_basket ship

// round variables to the nearest cent and fix negative shipping
replace prod_totprice=round(prod_totprice, 0.01)
replace ship_per=round(ship_per, 0.01)
replace ship_per=0 if ship_per<=0

// calculate another version of product level prices and drop extreme values.
gen prod_price=basket_tot*perc_basket
replace prod_price=round(prod_price, 0.01)
replace prod_price=. if prod_price<0
replace prod_price=. if prod_price>2000

replace prod_price=(1-tax)*prod_price

// generate demographic bins
gen age=.
replace age=1 if hoh_oldest_age==1 | hoh_oldest_age==2 
replace age=2 if hoh_oldest_age==3 | hoh_oldest_age==4 | hoh_oldest_age==5 | hoh_oldest_age==6 
replace age=3 if hoh_oldest_age==7 | hoh_oldest_age==8 | hoh_oldest_age==9 | hoh_oldest_age==10 
replace age=4 if hoh_oldest_age==11 
drop if age==.

gen race=6
replace race=1 if racial_background==1
replace race=2 if racial_background==2
replace race=3 if racial_background==3
replace race=4 if racial_background==5
drop if race==.

gen income_group=household_income
replace income_group=1 if income_group==1 | income_group==2 & year<=2013
replace income_group=2 if income_group==3 | income_group==4 | income_group==5 & year<=2013
replace income_group=3 if income_group==6 & year<=2013
replace income_group=4 if income_group==7 & year<=2013


replace income_group=1 if income_group==11 & year>=2014
replace income_group=2 if income_group==12 | income_group==13 | income_group==14 & year>=2014
replace income_group=3 if income_group==15 & year>=2014
replace income_group=4 if income_group>=16 & year>=2014

keep county race age income_group year prod_price mode year 


//merge in weights
merge m:1 county race age income_group year using "comscore_population_weight.dta"
keep if _merge==3
drop _merge


keep mode year county prod_price weight_county1 

sort county mode year prod_price
gen obs_id=_n

sort mode year prod_price
gen obs_id2=_n

****************************************************
****************************************************
****************************************************
****************************************************
****************************************************
****************************************************

// create average price
egen tot_tran_price_w1=sum(prod_price*weight_county1), by(county mode year)
egen tot_hh=sum(weight_county1), by(county mode year)
gen ave_tran_price_w1=tot_tran_price_w1/tot_hh


// create stdev of price
egen tot_tran_price_w1_var1=sum(prod_price*weight_county1), by(mode year)
gen ave_tran_price_w1_var2=tot_tran_price_w1_var1/tot_hh
egen tot_tran_price_w1_var=sum(weight_county1*(prod_price-ave_tran_price_w1_var2)^2), by(mode year)
gen stdev_tran_price_w1=sqrt(tot_tran_price_w1_var/tot_hh)

// create median of price
gen price_perc=w1/tot_hh
gen diff1=price_per-.5
replace diff1=. if diff1<0
egen min_diff=min(diff1), by(county mode year)
egen above50=max(prod_price*(min_diff==diff1)), by(county mode year)
gen diff2=.5-price_per
replace diff2=. if diff2<0
egen max_diff=min(diff2), by(county mode year)
egen below50=max(prod_price*(max_diff==diff2)), by(county mode year)
gen median_price_w1=below50+(abs(max_diff)/(abs(max_diff)+abs(min_diff)))*(above50-below50)
drop tot_tran_price_w1 tot_hh above50 below50 max_diff min_diff diff2 diff1 price_perc

egen tot_hh2=sum(weight_county1), by(mode year)

// create 75th percentile of price
gen price_perc=w12/tot_hh2
gen diff1=price_per-.75
replace diff1=. if diff1<0
egen min_diff=min(diff1), by(mode year)
egen above50=max(prod_price*(min_diff==diff1)), by(mode year)
gen diff2=.75-price_per
replace diff2=. if diff2<0
egen max_diff=min(diff2), by(mode year)
egen below50=max(prod_price*(max_diff==diff2)), by(mode year)
gen p75_price_w1=below50+(abs(max_diff)/(abs(max_diff)+abs(min_diff)))*(above50-below50)
drop above50 below50 max_diff min_diff diff2 diff1 price_perc tot_hh2

egen tot_hh2=sum(weight_county1), by(mode year)

//create 25th percentile of price
gen price_perc=w12/tot_hh2
gen diff1=price_per-.25
replace diff1=. if diff1<0
egen min_diff=min(diff1), by(mode year)
egen above50=max(prod_price*(min_diff==diff1)), by(mode year)
gen diff2=.25-price_per
replace diff2=. if diff2<0
egen max_diff=min(diff2), by(mode year)
egen below50=max(prod_price*(max_diff==diff2)), by(mode year)
gen p25_price_w1=below50+(abs(max_diff)/(abs(max_diff)+abs(min_diff)))*(above50-below50)
drop above50 below50 max_diff min_diff diff2 diff1 price_perc  tot_hh2

//final data cleaning
contract county year mode ave_tran_price_w* median_price_w* p75_price_w* p25_price_w* stdev_tran_price_w*
replace ave_tran_price_w1=. if ave_tran_price_w1==0

replace median_price_w1=. if median_price_w1==0
replace p75_price_w1=. if p75_price_w1==0
replace p25_price_w1=. if p25_price_w1==0
replace stdev_tran_price_w1=. if stdev_tran_price_w1==0

drop _freq

gen iquart_w1=p75_price_w1-p25_price_w1
keep county year mode ave_tran_price_w* median_price_w* iquart_w* stdev_tran_price_w*

save "ave_prices_w.dta", replace
