capture log close
set more off
clear
// Project: Nexus Tax Laws and Economies of Density in E-Commerce: A Study of Amazon’s Fulfillment Center Network
// Authors: Houde, Newberry, Seim
// Created by: Peter Newberry
// Date: 05/2022
// Description: Creates Tables 3 in the paper and data set to take to supply side.
// Data sets needed: hh_expenditures.dta: created by authors in DOFILE from propreitary data.
//					 comscore_population_weight.dta: population weights based on census data and comscore data. 
//  				 demo_panel_final_mode.dta: county demographics, etc., created by authors. Just county_panel repeated three times...once for each mode.
//                   infaltion_factors.dta: national level data on how much spending needs to be "blown up". Created by authors.
// 					 State_census_codes.dta: FIPS codes for each state as well as Census region and district for each state. Available from Census. 
// 					 county_date_FC.dta: created by authors. indicates the date of opening of the first FC in each county (conditional on that county having one by the end of the sample)
//					 aggregate_financials.dta: data from amazon's financial reports.
//					 Panel_county_tax_dist.dta: has county level tax information as well as information on distances to FCs and SCS. The tax information is propreitary. Souces is TDS (tax data systems).It also has whether or not transacitons in the year/mode are taxable. 
//					 ave_prices_w.dta: created by authors from comScore data (propreitary) Has different measures of average prices and price dispersion.
// Author notes: based on author do-file "ces_model.do"

******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
//Creates table 3 in the paper


******************************************************************************
******************************************************************************
******************************************************************************
//First part creates the spending for each mode/county

// Upload spending data at the household level.
use "hh_expenditures.dta", clear

// Merge in population weights based on observed demographics. 
sort  county race age income_group year
merge county race age income_group year using "comscore_population_weight.dta"
drop if _merge==2
drop _merge
rename tot_hh tot_hh_cs

// Generate the total number of households 
drop dum
gen dum=1
egen hh_samp=sum(dum), by(county year)

// Merge in the amount that the data is "blown up" to account for missing data.
sort year
merge year using "infaltion_factors.dta"
tab _merge
drop _merge

// Generatge spending data by summing over households in a county using the population weights and accounting for missing data.
egen tot_hh_forr=sum(weight_county1), by(county year)
replace tot_hh_forr=tot_hh_forr
egen tot_hh_temp=max(tot_hh_forr), by(county year)
replace tot_hh_forr=tot_hh_temp
drop tot_hh_temp

egen tot_exp_forr_county1=sum(1/(1-missing_perc_amazon_county_forr)*tot_exp1_forr*weight_county1), by(county year)
egen tot_exp_forr_county2=sum(1/(1-missing_perc_all_county_forr)*tot_exp2_forr*weight_county1), by(county year)
egen tot_exp_forr_county3=sum(1/(1-missing_perc_all_county_forr)*tot_exp3_forr*weight_county1), by(county year)

gen exp_county_forr1=tot_exp_forr_county1/tot_hh_forr
gen exp_county_forr2=tot_exp_forr_county2/tot_hh_forr
gen exp_county_forr3=tot_exp_forr_county3/tot_hh_forr


// generate pricing data by summing over households in a county using the population weights
egen tot_hh_forr2=sum(weight_county1*(med_tran_price1~=.)), by(county year)
replace tot_hh_forr2=tot_hh_forr2
egen tot_hh_temp2=max(tot_hh_forr2), by(county year)
replace tot_hh_forr2=tot_hh_temp2
drop tot_hh_temp2


// Contract at the county level.
contract  year county median_age median_income White_share Asian_share Black_share Other_share  exp_county_forr* e  hh_samp 
drop _freq

// Generate a temporary county level data set with demographics.
preserve
contract year county median_age median_income White_share Asian_share Black_share Other_share hh_samp
drop _freq
sort county year
save "county_cs_demos.dta", replace 
restore

// reshape to get expenditures for each county
reshape long exp_county_forr , i(year county) j(mode)


******************************************************************************
******************************************************************************
******************************************************************************
// Second part merges in various data sets

// Merge in demographics for consumers.
sort county year mode
merge county year mode using "demo_panel_final_mode.dta"
tab _merge
drop _merge

// Merge in state FIPS codes as well as Census region district.
replace state=trim(state)
sort state
merge m:1 state using "State_census_codes.dta"
keep if _merge==3
drop _merge

rename state state2
rename state_abbrev state

rename census_region region
rename census_division district

// Merge county demos back in
sort county year
merge county year using "county_cs_demos.dta"
drop _merge
erase "county_cs_demos.dta"

// Merge in date in which each county got its first FC.
sort county_code 
merge county_code using "county_date_FC.dta"
tab _merge
drop _merge

// Merge in some financial information.
merge m:1 year using "aggregate_financials.dta"
drop _merge

// Generate new variables representing the products purchased per household. 
gen prods_per=prods_per1 if mode==1
replace prods_per=prods_per2 if mode==2
replace prods_per=prods_per3 if mode==3

// Merge in tax rate data as well as distances (which we don't use here)
merge m:1 county_code year using "Panel_county_tax_dist.dta"
tab _merge
keep if _merge==3
drop _merge

// merge in price data
merge m:1 county year mode using "ave_prices_w.dta"
drop if _merge==2
drop _merge


******************************************************************************
******************************************************************************
******************************************************************************
// Third part creates variables for the regression

// Drop blank obs with no state information.
drop if state==""
// drop if don't have the mode
drop if mode==.

// erase a label so can identify the type
label drop typeid

// Generate tax variables
gen tax_status=dummy_taxable
replace tax_status=1 if mode==2
replace tax_status=0 if mode==3

gen tax_rate=tax
gen tax2=tax
replace tax2=tax_status*tax_rate
replace tax=tax2 
drop tax2

// Generate the share of goods that Amazon is selling directly (not 3rd party)
gen am_share=1-mp_share

//generage the log of the tax variable, correcting for the share of 3rd party sales.
gen lg_tax=log(1+tax)*(mode~=1)+log(1+(am_share)*tax)*(mode==1)
gen lg_tax_mp=log(1+tax)*(mode~=1)+log(1+tax)*(mode==1)

// generate tax variable for regression.
gen tax_diff=lg_tax-log(1+tax_rate)
replace tax_diff=0 if mode==2

gen tax_diff_mp=lg_tax_mp-log(1+tax_rate)
replace tax_diff_mp=0 if mode==2

// Generate aggreagate density variable. Don't use this here, so set to 0
gen density1==0

// Caclualte total Households across all the counties
egen tot_households=sum(nb_hh), by(year mode)

// Create the averate age from the age bins. 
gen mean_age=dummy_age_15_25*20+dummy_age_25_35*30+dummy_age_35_45*40+dummy_age_45_55*50+dummy_age_55_60*57.5+dummy_age_60_65*62.5+dummy_age_65_75*70+dummy_age_75_plus*80

// generate perc of pop under 35
gen perc_u35=dummy_age_15_25 +dummy_age_25_35

// generate perc of pop above income 100k
gen perc_100=hhincome_100000to124999+ hhincome_125000to149999+ hhincome_150000to199999+ hhincome_200000ormore

// at the time of analysis, did not have demographic information for 2016-2018 so assume it is constant
egen mean_age_2016=max(mean_age*(year==2015)), by(county mode)
replace mean_age=mean_age_2016 if year==2017 | year==2018 | year==2016  
egen median_income_2016=max(median_income*(year==2015)), by(county mode)
replace median_income=median_income_2016 if year==2017 | year==2018 | year==2016
egen pop_density_2016=max(pop_density*(year==2015)), by(county mode)
replace pop_density=pop_density_2016 if year==2017 | year==2018 | year==2016
egen perc_100_2016=max(perc_100*(year==2015)), by(county mode)
replace perc_100=perc_100_2016 if year==2017 | year==2018 | year==2016
egen perc_u35_2016=max(perc_u35*(year==2015)), by(county mode)
replace perc_u35=perc_u35_2016 if year==2017 | year==2018 | year==2016
egen dummy_black_2016=max(dummy_black*(year==2015)), by(county mode)
replace dummy_black=dummy_black_2016 if year==2017 | year==2018 | year==2016
egen dummy_asian_2016=max(dummy_asian*(year==2015)), by(county mode)
replace dummy_asian=dummy_asian_2016 if year==2017 | year==2018 | year==2016
egen tot_big_2016=max(tot_big*(year==2015)), by(county mode)
replace tot_big=tot_big_2016 if year==2017 | year==2018 | year==2016
egen tot_small_2016=max(tot_small*(year==2015)), by(county mode)
replace tot_small=tot_small_2016 if year==2017 | year==2018 | year==2016

//generate log median income.
gen lg_income=log(median_income)
//generate log mean income.
gen lg_inc=log(mean_income)

// create mode level variables for the demographics and dummy variables.
forvalues m=1/3{
forvalues y=1999/2018{
gen mode`m'year`y'=(mode==`m' & year==`y')

}
gen estab_mode`m'=(mode==`m')*tot_small
gen estab50_mode`m'=(mode==`m')*tot_big
gen age_mode`m'=(mode==`m')*mean_age
gen income_mode`m'=(mode==`m')*log(median_income)
gen black_mode`m'=(mode==`m')*dummy_black
gen asian_mode`m'=(mode==`m')*dummy_asian
gen tax_mode`m'=(mode==`m')*tax_diff
gen dens_mode`m'=(mode==`m')*log(pop_density)
gen income_mode`m'_2=(mode==`m')*lg_inc

}
// rename income for mode1 to amazon.
rename income_mode1 am_lg_income
rename income_mode1_2 am_lg_inc

// generate age variable and rename mode 1 to amazon
gen age=mean_age
rename age_mode1 am_age

// generate log of pop density and amazon version
gen lg_dens=log(pop_density)
gen am_lg_dens=log(pop_density)*(mode==1)

// generate tax variable interacted with percent of population who have income above 100
gen tax_diff100=tax_diff*(perc_100)

//generate race variables
gen perc_black=dummy_black
gen perc_asian=dummy_asian

// generate amazon specific demo variables.
gen am_perc_u35=perc_u35*(mode==1)
gen am_perc_black=dummy_black*(mode==1)
gen am_perc_asian=dummy_asian*(mode==1)
gen am_perc_100=perc_100*(mode==1)

// create number of big, small, and total retailers per capita and the amazon interaction of the same variables 
gen big_per_cap=tot_big/population*1000
gen small_per_cap=tot_small/population*1000
gen tot_per_cap=(tot_small+tot_big)/population*1000

gen am_big_per_cap=tot_big/population*1000*(mode==1)
gen am_small_per_cap=tot_small/population*1000*(mode==1)
gen am_tot_per_cap=(tot_small+tot_big)/population*1000*(mode==1)

// generate district/year dummy variables
forvalues d=1/9{
forvalues y=1999/2018{
gen dist`d'year`y'=(district==`d' & year==`y')
}
}

// generate total online spending
egen online_forr=sum(exp_county_forr), by(year county)

// generate dependant variable for regression subtract tax_diff variable so that coefficient on tax diff is sigma (in the formulation it is 1+sigma)
gen dep_var_forr=log(exp_county_forr)-log(avg_spending_annual_county-online_forr)-tax_diff

// save a data set that i can put just before regressions.
save "ces_data_regs.dta", replace

// create summary file taht we can take to create descriptive maps
preserve
keep county year exp_county_forr mode state_code pop_density mean_income region nb_hh
keep if mode==1
keep if year>=2006 & year<=2016
keep county year exp_county_forr state_code pop_density mean_income region nb_hh
save "spending_data_summary2.dta", replace
restore

******************************************************************************
******************************************************************************
******************************************************************************
// Fourth part runs the regressions


// homogenous tax coefficient
areg dep_var_forr tax_diff mode1year2006-mode1year2016 mode2year2006-mode2year2016 mode3year2006-mode3year2016  ///
tot_per_cap am_tot_per_cap small_per_cap am_small_per_cap lg_dens am_lg_dens perc_100 am_perc_100 perc_u35 am_perc_u35 perc_black am_perc_black perc_asian am_perc_asian ///
age am_age lg_inc am_lg_inc ///
dist1year2006-dist1year2016 dist2year2006-dist2year2016 dist3year2006-dist3year2016 ///
dist4year2006-dist4year2016 dist5year2006-dist5year2016 dist6year2006-dist6year2016 dist7year2006-dist7year2016 ///
dist8year2006-dist8year2016 dist9year2006-dist9year2016 [w=hh_samp], absorb(county)

estout using "ces_noint.csv", cells(b se) delimiter(,) replace collabels(none)

// heterogenous tax coefficient
areg dep_var_forr tax_diff tax_diff100 mode1year2006-mode1year2016 mode2year2006-mode2year2016 mode3year2006-mode3year2016  ///
tot_per_cap am_tot_per_cap small_per_cap am_small_per_cap lg_dens am_lg_dens perc_100 am_perc_100 perc_u35 am_perc_u35 perc_black am_perc_black perc_asian am_perc_asian ///
age am_age lg_inc am_lg_inc ///
dist1year2006-dist1year2016 dist2year2006-dist2year2016 dist3year2006-dist3year2016 ///
dist4year2006-dist4year2016 dist5year2006-dist5year2016 dist6year2006-dist6year2016 dist7year2006-dist7year2016 ///
dist8year2006-dist8year2016 dist9year2006-dist9year2016 [w=hh_samp], absorb(county)
estout using "ces_int_region.csv", cells(b se) delimiter(,) replace collabels(none)

estout using "ces_int2.csv", cells(b p) delimiter(,) replace collabels(none)
estout using "ces_int.csv", cells(b se) delimiter(,) replace collabels(none)

******************************************************************************
******************************************************************************
******************************************************************************
// Fifth part is postestimation to create data set to take to supply side including out of sample data.


// get fixed effects for mode-year and district
gen mode_fe=_b[mode1year2006]*mode1year2006+_b[mode1year2007]*mode1year2007+_b[mode1year2008]*mode1year2008+_b[mode1year2009]*mode1year2009 ///
+_b[mode1year2010]*mode1year2010+_b[mode1year2011]*mode1year2011+_b[mode1year2012]*mode1year2012+_b[mode1year2013]*mode1year2013 ///
+_b[mode1year2014]*mode1year2014+_b[mode1year2015]*mode1year2015+_b[mode1year2016]*mode1year2016 ///
+_b[mode2year2006]*mode2year2006+_b[mode2year2007]*mode2year2007+_b[mode2year2008]*mode2year2008+_b[mode2year2009]*mode2year2009 ///
+_b[mode2year2010]*mode2year2010+_b[mode2year2011]*mode2year2011+_b[mode2year2012]*mode2year2012+_b[mode2year2013]*mode2year2013 ///
+_b[mode2year2014]*mode2year2014+_b[mode2year2015]*mode2year2015+_b[mode2year2016]*mode2year2016 ///
+_b[mode3year2006]*mode3year2006+_b[mode3year2007]*mode3year2007+_b[mode3year2008]*mode3year2008+_b[mode3year2009]*mode3year2009 ///
+_b[mode3year2010]*mode3year2010+_b[mode3year2011]*mode3year2011+_b[mode3year2012]*mode3year2012+_b[mode3year2013]*mode3year2013 ///
+_b[mode3year2014]*mode3year2014+_b[mode3year2015]*mode3year2015

gen region_fe=_b[dist1year2006]*dist1year2006+_b[dist1year2007]*dist1year2007+_b[dist1year2008]*dist1year2008 ///
+_b[dist1year2009]*dist1year2009+_b[dist1year2010]*dist1year2010+_b[dist1year2011]*dist1year2011 ///
+_b[dist1year2012]*dist1year2012+_b[dist1year2013]*dist1year2013+_b[dist1year2014]*dist1year2014 ///
+_b[dist1year2015]*dist1year2015 ///
+_b[dist2year2006]*dist2year2006+_b[dist2year2007]*dist2year2007+_b[dist2year2008]*dist2year2008 ///
+_b[dist2year2009]*dist2year2009+_b[dist2year2010]*dist2year2010+_b[dist2year2011]*dist2year2011 ///
+_b[dist2year2012]*dist2year2012+_b[dist2year2013]*dist2year2013+_b[dist2year2014]*dist2year2014 ///
+_b[dist2year2015]*dist2year2015 ///
+_b[dist3year2006]*dist3year2006+_b[dist3year2007]*dist3year2007+_b[dist3year2008]*dist3year2008 ///
+_b[dist3year2009]*dist3year2009+_b[dist3year2010]*dist3year2010+_b[dist3year2011]*dist3year2011 ///
+_b[dist3year2012]*dist3year2012+_b[dist3year2013]*dist3year2013+_b[dist3year2014]*dist3year2014 ///
+_b[dist3year2015]*dist3year2015 ///
+_b[dist4year2006]*dist4year2006+_b[dist4year2007]*dist4year2007+_b[dist4year2008]*dist4year2008 ///
+_b[dist4year2009]*dist4year2009+_b[dist4year2010]*dist4year2010+_b[dist4year2011]*dist4year2011 ///
+_b[dist4year2012]*dist4year2012+_b[dist4year2013]*dist4year2013+_b[dist4year2014]*dist4year2014 ///
+_b[dist4year2015]*dist4year2015 ///
+_b[dist5year2006]*dist5year2006+_b[dist5year2007]*dist5year2007+_b[dist5year2008]*dist5year2008 ///
+_b[dist5year2009]*dist5year2009+_b[dist5year2010]*dist5year2010+_b[dist5year2011]*dist5year2011 ///
+_b[dist5year2012]*dist5year2012+_b[dist5year2013]*dist5year2013+_b[dist5year2014]*dist5year2014 ///
+_b[dist5year2015]*dist5year2015 ///
+_b[dist6year2006]*dist6year2006+_b[dist6year2007]*dist6year2007+_b[dist6year2008]*dist6year2008 ///
+_b[dist6year2009]*dist6year2009+_b[dist6year2010]*dist6year2010+_b[dist6year2011]*dist6year2011 ///
+_b[dist6year2012]*dist6year2012+_b[dist6year2013]*dist6year2013+_b[dist6year2014]*dist6year2014 ///
+_b[dist6year2015]*dist6year2015 ///
+_b[dist7year2006]*dist7year2006+_b[dist7year2007]*dist7year2007+_b[dist7year2008]*dist7year2008 ///
+_b[dist7year2009]*dist7year2009+_b[dist7year2010]*dist7year2010+_b[dist7year2011]*dist7year2011 ///
+_b[dist7year2012]*dist7year2012+_b[dist7year2013]*dist7year2013+_b[dist7year2014]*dist7year2014 ///
+_b[dist7year2015]*dist7year2015 ///
+_b[dist8year2006]*dist8year2006+_b[dist8year2007]*dist8year2007+_b[dist8year2008]*dist8year2008 ///
+_b[dist8year2009]*dist8year2009+_b[dist8year2010]*dist8year2010+_b[dist8year2011]*dist8year2011 ///
+_b[dist8year2012]*dist8year2012+_b[dist8year2013]*dist8year2013+_b[dist8year2014]*dist8year2014 ///
+_b[dist8year2015]*dist8year2015

replace region_fe=0 if region_fe==.

// get tax coefficients
gen tax_coeff=_b[tax_diff]
gen tax_coeff100=_b[tax_diff100]

// get sigma from tax coeffcicients. 
gen sigma=_b[tax_diff]+_b[tax_diff100]*perc_100


// descriptive statistics on estimate of sigma
preserve
keep if mode==1
egen tot_sigma=sum(nb_hh*sigma), by(year state)
egen tot_hh=sum(nb_hh), by(year state)
gen mean_sigma=tot_sigma/tot_hh
contract mean_sigma state year
bysort year: summ mean_sigma, det

restore

preserve
keep if mode==1
egen tot_sigma=sum(nb_hh*sigma), by(state)
egen tot_hh=sum(nb_hh), by(state)
gen mean_sigma=tot_sigma/tot_hh
contract mean_sigma state
summ mean_sigma, det
restore

// get the county fixed effect
predict cfe, d

//rename county fe
gen a_it=cfe

// predict spending from regression (minus thefied county FE)
predict pre_dep_tmp, xb

// generate the local preferences minues the FEs (this does not include the tax variable)
gen loc_pref=_b[tot_per_cap]*tot_per_cap+_b[am_tot_per_cap]*am_tot_per_cap +_b[small_per_cap]*small_per_cap +_b[am_small_per_cap]*am_small_per_cap /// 
+_b[lg_dens]*lg_dens +_b[am_lg_dens]*am_lg_dens +_b[perc_100]*perc_100 +_b[am_perc_100]*am_perc_100 +_b[perc_u35]*perc_u35 +_b[am_perc_u35]*am_perc_u35 ///
+_b[perc_black]*perc_black +_b[am_perc_black]*am_perc_black +_b[perc_asian]*perc_asian +_b[am_perc_asian]*am_perc_asian ///
+_b[age]*age +_b[am_age]*am_age +_b[lg_inc]*lg_inc +_b[am_lg_inc]*am_lg_inc

// we now have to predict the region/year FE out of sample in order to predict spening out of sample
// create a data set that is each district and year.
preserve 
contract year
drop _freq
gen district=1
save "tmp1.dta", replace
replace district=2
save "tmp2.dta", replace
replace district=3
save "tmp3.dta", replace
replace district=4
save "tmp4.dta", replace
replace district=5
save "tmp5.dta", replace
replace district=6
save "tmp6.dta", replace
replace district=7
save "tmp7.dta", replace
replace district=8
save "tmp8.dta", replace

use "tmp1.dta"
append using "tmp2.dta"
append using "tmp3.dta"
append using "tmp4.dta"
append using "tmp5.dta"
append using "tmp6.dta"
append using "tmp7.dta"
append using "tmp8.dta"
save "tmp.dta", replace
erase "tmp1.dta"
erase "tmp2.dta"
erase "tmp3.dta"
erase "tmp4.dta"
erase "tmp5.dta"
erase "tmp6.dta"
erase "tmp7.dta"
erase "tmp8.dta"

// insheet the district year FE estimates.
insheet using "es_int_region.csv", comma clear
drop if v2==0
drop if v2==.
gen stderr_ind= v1==""
replace v1=v1[_n-1] if v1==""
keep if strpos(v1, "dist")>0
gen dist=substr(v1, 5, 1)
gen year=substr(v1, 10,4)
destring dist, replace
destring year, replace
drop if stderr_ind==1
drop v1
rename v2 param
drop stderr_ind
rename dist district

merge m:1 year dist using "tmp.dta"
drop _merge
erase "tmp.dta"

// run a regression of dist/year FEs on a time trend and time trend squared for each district and then use the predictions to form the region year_fe out (and in) sample
gen time=year-1998
gen time_sq=time^2
replace param=0 if year==2016
reg param time time_sq if district==1
gen region_fe_pre=.
predict region_fe_tmp, xb
replace region_fe_pre=region_fe_tmp if district==1
drop region_fe_tmp
reg param time time_sq if district==2
predict region_fe_tmp, xb
replace region_fe_pre=region_fe_tmp if district==2
drop region_fe_tmp
reg param time time_sq if district==3
predict region_fe_tmp, xb
replace region_fe_pre=region_fe_tmp if district==3
drop region_fe_tmp
reg param time time_sq if district==4
predict region_fe_tmp, xb
replace region_fe_pre=region_fe_tmp if district==4
drop region_fe_tmp
reg param time time_sq if district==5
predict region_fe_tmp, xb
replace region_fe_pre=region_fe_tmp if district==5
drop region_fe_tmp
reg param time time_sq if district==6
predict region_fe_tmp, xb
replace region_fe_pre=region_fe_tmp if district==6
drop region_fe_tmp
reg param time time_sq if district==7
predict region_fe_tmp, xb
replace region_fe_pre=region_fe_tmp if district==7
drop region_fe_tmp
reg param time time_sq if district==8
predict region_fe_tmp, xb
replace region_fe_pre=region_fe_tmp if district==8
drop region_fe_tmp
keep district year region_fe_pre
save "region_fe.dta", replace
restore


// merge in predicted region/year FEs
merge m:1 district year using "region_fe.dta"
drop _merge
replace region_fe_pre=0 if district==9

// add the tax diff variable because i subracted it from the DV before regression and then substitute predicted region FE
replace pre_dep_tmp=pre_dep_tmp+tax_diff-region_fe+region_fe_pre

// get mean squared error from regressions
gen mse=e(rmse)^2/2

// need to predict county FEs for counties that we don't have observations in comScore. To do so, regress the county FEs on county demographics.
preserve
egen tot_hh_samp=sum(hh_samp), by(county mode)

// create future values of demographics (that we didn't observe at the time of analysis)
foreach var in tot_per_cap small_per_cap median_value dummy_unemployed dummy_laborforce dummy_college dummy_age_15_25 dummy_age_25_35 dummy_age_35_45 dummy_age_45_55 dummy_age_55_60 dummy_age_60_65 dummy_age_65_75 dummy_age_75_plus hhincome_lessthan20000 hhincome_20000to24999 hhincome_25000to29999 hhincome_30000to34999 hhincome_35000to39999 hhincome_40000to44999 hhincome_45000to49999 hhincome_50000to59999 hhincome_60000to74999 hhincome_75000to99999 hhincome_100000to124999 hhincome_125000to149999 hhincome_150000to199999 hhincome_200000ormore lg_dens {
*************************************************************************
egen `var'_2016=max(`var'*(year==2015)), by(county mode)
replace `var'=`var'_2016 if year==2017 | year==2018 | year==2016
*************************************************************************
}

// collapse to a single observation for each county, so we mean the demographics.
collapse (mean) a_it tot_hh_samp tot_per_cap small_per_cap median_value dummy_unemployed dummy_laborforce dummy_college dummy_age_15_25 dummy_age_25_35 dummy_age_35_45 dummy_age_45_55 dummy_age_55_60 dummy_age_60_65 dummy_age_65_75 dummy_age_75_plus hhincome_lessthan20000 hhincome_20000to24999 hhincome_25000to29999 hhincome_30000to34999 hhincome_35000to39999 hhincome_40000to44999 hhincome_45000to49999 hhincome_50000to59999 hhincome_60000to74999 hhincome_75000to99999 hhincome_100000to124999 hhincome_125000to149999 hhincome_150000to199999 hhincome_200000ormore lg_dens, by(county state_code) 

// run the regressions.
reg a_it tot_per_cap small_per_cap dummy_age_15_25 dummy_age_25_35 dummy_age_35_45 dummy_age_45_55 dummy_age_55_60 dummy_age_60_65 dummy_age_65_75 dummy_age_75_plus hhincome_lessthan20000 hhincome_20000to24999 hhincome_25000to29999 hhincome_30000to34999 hhincome_35000to39999 hhincome_40000to44999 hhincome_45000to49999 hhincome_50000to59999 hhincome_60000to74999 hhincome_75000to99999 hhincome_100000to124999 hhincome_125000to149999 hhincome_150000to199999 hhincome_200000ormore lg_dens  i.state_code [w=tot_hh_samp]

//predict the county FE based on regression
predict county_fe, xb

keep county county_fe
save "county_fe.dta", replace
restore

// merge in predicted county FE
merge m:1 county using "county_fe.dta"
drop _merge 

// adjustment used in an earlier version. no longer use this
gen tax_rhs=((1+tax)*(mode~=1)+(1+(1-mp_share)*tax)*(mode==1))/(1+tax_rate)

// adjustment to transform tax inclusive revenue to just revenue
gen adjustment=1/(1+amazon_tax*(1-mp_share)) if mode==1
replace adjustment=1/(1+tax) if mode==2
replace adjustment=1 if mode==3

// calculate delta minus the mode FE.
gen delta=pre_dep_tmp+county_fe+mse-mode_fe

// add the county FE into the loc preferences
replace loc_pref=county_fe+loc_pref

// create data set to take to Matlab to estimate the mode level FE from the model estimates and the sales data from Amazon’s financial statements and US dept of commerce
preserve
keep mode year county delta mode_fe avg_spending_annual_county tax_rhs adjustment amazon_sales mode2_sales0 mode3_sales0 nb_hh
order mode year county delta mode_fe avg_spending_annual_county tax_rhs adjustment amazon_sales mode2_sales0 mode3_sales0 nb_hh
outsheet using "projected_fe_wf.csv", comma replace nonames
restore

*******************************
//RUN fe_project_estimates.m IN MATLAB AND THEN CONTINUE PROGRAM HERE
pause
*******************************

// open up fe_project_estimates.m in matlab and run. This outputs the projected mode FEs
// after run matlab program, come back and continue stata program


// input projected mode FEs.
preserve
insheet using "projected_fe.csv", comma nonames clear
rename v1 year
rename v2 mode
rename v3 mode_fe_project
save "projected_fe.dta", replace
restore

// merge in projected FEs
merge m:1 year mode using "projected_fe.dta"
//replace current FEs with projected FEs
replace mode_fe=mode_fe_project

//predicted depedant variable
gen pre_dep=exp(delta+mode_fe) 

//predicted depedant variable by mode
gen pre_dep1_tmp=pre_dep if mode==1
egen pre_dep_1=max(pre_dep1_tmp), by(county year)
replace pre_dep_1=0 if pre_dep_1==.

gen pre_dep2_tmp=pre_dep if mode==2
egen pre_dep_2=max(pre_dep2_tmp), by(county year)
replace pre_dep_2=0 if pre_dep_2==.

gen pre_dep3_tmp=pre_dep if mode==3
egen pre_dep_3=max(pre_dep3_tmp), by(county year)
replace pre_dep_3=0 if pre_dep_3==.


// calculate expenditures for each mode
gen pred0=(avg_spending_annual_county)/(1+pre_dep_1+pre_dep_2+pre_dep_3)
gen pred1=pre_dep_1*pred0
gen pred2=pre_dep_2*pred0
gen pred3=pre_dep_3*pred0

// adjust by taxes to get revenue net of taxes
gen pre_exp=pred1*1/(1+amazon_tax*(1-mp_share)) if mode==1
replace pre_exp=pred2*1/(1+tax) if mode==2
replace pre_exp=pred3 if mode==3

 
// calculate offline expenditures
egen exp_tmp=sum(pre_exp), by(county year)
gen off_pre_exp=(avg_spending_annual_county)-exp_tmp


// aggregate up to the county
gen pre_exp_county=pre_exp*nb_hh

//total county only spending
egen tot_exp=sum(pre_exp_county), by(year mode)

// total households with non-empty spending
egen tot_hh=sum(nb_hh*(pre_exp~=.)), by(year mode)

// adjust observed expenditures by tax to get revenue net of tax
gen exp_county2=exp_county_forr*1/(1+amazon_tax*(1-mp_share)) if mode==1
replace exp_county2=exp_county_forr*1/(1+tax) if mode==2
replace exp_county2=exp_county_forr if mode==3

// generate true total expenditures by mode/year
egen tot_exp_true=sum(exp_county2*nb_hh), by(year mode)
// total households with spending in the obserbed spending data
egen tot_hh_true=sum((exp_county_forr~=.)*nb_hh), by(year mode)


// format variables so can see them better. At this point can check yearley spending to see if it matches the financial reports and us dept of commerce data
format tot_exp %15.5g
format tot_exp_true %15.5g
format tot_hh_true %15.5g
format tot_hh %15.5g

// If doing analysis on aggregate density could use a regression of FE on density to get FE. We dropped this analysis. 
gen density_param=0

******************************************************************************
******************************************************************************
******************************************************************************
// sixth part is to generate price data and measure of variety

// for each mode run regressions of prices (mean and median, log and levels) on time trends and measure of income. Use the regressions to predict prices in each county/mode/year.
// mode 1
preserve
keep if mode==1
gen time=year-2006
gen time_inc=time*perc_100

gen lg_aprice1=log(ave_tran_price_w1)

gen lg_mprice1=log(median_price_w1)

// average prices
reg ave_tran_price_w1 time perc_100 [w=hh_samp] if mode==1
predict pre_aprice1, xb

// log average prices
reg lg_aprice1 time perc_100 [w=hh_samp] if mode==1
predict pre_aprice_tmp, xb
gen pre_laprice1=exp(pre_aprice_tmp+e(rmse)^2/2)
drop pre_aprice_tmp


// median prices
reg median_price_w1 time perc_100 [w=hh_samp] if mode==1
predict pre_mprice1, xb

// log median prices
reg lg_mprice1 time perc_100 [w=hh_samp] if mode==1
predict pre_aprice_tmp, xb
gen pre_lmprice1=exp(pre_aprice_tmp+e(rmse)^2/2)
drop pre_aprice_tmp

keep year county mode pre_aprice* pre_laprice* pre_mprice* pre_lmprice*
save "county_prices1.dta", replace
restore

// mode 2
preserve
keep if mode==2
gen time=year-2006
gen time_inc=time*perc_100

gen lg_aprice1=log(ave_tran_price_w1)

gen lg_mprice1=log(median_price_w1)

// average prices
reg ave_tran_price_w1 time perc_100 [w=hh_samp] if mode==2
predict pre_aprice1, xb

// log average prices
reg lg_aprice1 time perc_100 [w=hh_samp] if mode==2
predict pre_aprice_tmp, xb
gen pre_laprice1=exp(pre_aprice_tmp+e(rmse)^2/2)
drop pre_aprice_tmp

// median prices
reg median_price_w1 time perc_100 [w=hh_samp] if mode==2
predict pre_mprice1, xb


// log median prices
reg lg_mprice1 time perc_100 [w=hh_samp] if mode==2
predict pre_aprice_tmp, xb
gen pre_lmprice1=exp(pre_aprice_tmp+e(rmse)^2/2)
drop pre_aprice_tmp

keep year county mode pre_aprice* pre_laprice* pre_mprice* pre_lmprice*
save "county_prices2.dta", replace
restore

// mode 3
preserve
keep if mode==3
gen time=year-2006
gen time_inc=time*perc_100

gen lg_aprice1=log(ave_tran_price_w1)
gen lg_mprice1=log(median_price_w1)

// average prices
reg ave_tran_price_w1 time perc_100 [w=hh_samp] if mode==3
predict pre_aprice1, xb

// log average prices
reg lg_aprice1 time perc_100 [w=hh_samp] if mode==3
predict pre_aprice_tmp, xb
gen pre_laprice1=exp(pre_aprice_tmp+e(rmse)^2/2)
drop pre_aprice_tmp

// median prices
reg median_price_w1 time perc_100 [w=hh_samp] if mode==3
predict pre_mprice1, xb

// log median prices
reg lg_mprice1 time perc_100 [w=hh_samp] if mode==3
predict pre_aprice_tmp, xb
gen pre_lmprice1=exp(pre_aprice_tmp+e(rmse)^2/2)
drop pre_aprice_tmp


keep year county mode pre_aprice* pre_laprice* pre_mprice* pre_lmprice*
save "county_prices3.dta", replace
restore

// append price data together and merge back in
preserve
use "county_prices1.dta", clear
append using "county_prices2.dta"
append using "county_prices3.dta"
save "county_prices.dta", replace
restore

merge 1:1 year county mode using "county_prices.dta"
drop _merge


gen time=year-2006
gen time_inc=time*perc_100
// for each mode run regressions of price dispersion (interquartile range and standard deviation, logs and levels) on time trends. Use the regressions to predict price dispersion for each mode/year. 
// mode 1
preserve
keep if mode==1
contract iquart_w1  time mode year stdev_tran_price_w1 

// interquartile range and log interquartile range
reg iquart_w1 time if mode==1
predict pre_iquart1, xb
gen lg_iquart1=log(iquart_w1)
reg lg_iquart1 time if mode==1
predict pre_iquart_tmp, xb
gen pre_liquart1=exp(pre_iquart_tmp+e(rmse)^2/2)
drop pre_iquart_tmp

reg stdev_tran_price_w1 time if mode==1
predict pre_std1, xb
gen lg_std1=log(stdev_tran_price_w1)
reg lg_std1 time if mode==1
predict pre_std_tmp, xb
gen pre_lstd1=exp(pre_std_tmp+e(rmse)^2/2)
drop pre_std_tmp


keep year mode pre_iquart1 pre_liquart1 pre_std1  pre_lstd1 

contract year mode pre_iquart1  pre_liquart1 pre_std1 pre_lstd1
drop _freq
save "pre_iquart1.dta", replace
restore


//mode 2
preserve
keep if mode==2
contract iquart_w1 time mode year  stdev_tran_price_w1 

// interquartile range and log interquartile range
reg iquart_w1 time if mode==2
predict pre_iquart1, xb
gen lg_iquart1=log(iquart_w1)
reg lg_iquart1 time if mode==2
predict pre_iquart_tmp, xb
gen pre_liquart1=exp(pre_iquart_tmp+e(rmse)^2/2)
drop pre_iquart_tmp

// standard deviation and log standard deviation
reg stdev_tran_price_w1 time if mode==2
predict pre_std1, xb
gen lg_std1=log(stdev_tran_price_w1)
reg lg_std1 time if mode==2
predict pre_std_tmp, xb
gen pre_lstd1=exp(pre_std_tmp+e(rmse)^2/2)
drop pre_std_tmp


keep year mode pre_iquart1  pre_liquart1  pre_std1 pre_lstd1 
contract year mode pre_iquart1  pre_liquart1  pre_std1  pre_lstd1 
drop _freq
save "pre_iquart2.dta", replace
restore


//mode 3
preserve
keep if mode==3
contract iquart_w1 time mode year  stdev_tran_price_w1 

// interquartile range and log interquartile range
reg iquart_w1 time if mode==3
predict pre_iquart1, xb
gen lg_iquart1=log(iquart_w1)
reg lg_iquart1 time if mode==3
predict pre_iquart_tmp, xb
gen pre_liquart1=exp(pre_iquart_tmp+e(rmse)^2/2)
drop pre_iquart_tmp


// standard deviation and log standard deviation
reg stdev_tran_price_w1 time if mode==3
predict pre_std1, xb
gen lg_std1=log(stdev_tran_price_w1)
reg lg_std1 time if mode==3
predict pre_std_tmp, xb
gen pre_lstd1=exp(pre_std_tmp+e(rmse)^2/2)
drop pre_std_tmp 

keep year mode pre_iquart1  pre_liquart1  pre_std1  pre_lstd1 
contract year mode pre_iquart1 pre_liquart1 pre_std1  pre_lstd1 
drop _freq
save "pre_iquart3.dta", replace
restore


// append the data together.
preserve 
use "pre_iquart1.dta", clear
append using "pre_iquart2.dta"
append using "pre_iquart3.dta"
save "pre_iquart.dta", replace
restore


// merge data back in
merge m:1 year mode using "pre_iquart.dta"
drop _merge


******************************************************************************
******************************************************************************
******************************************************************************
// seventh part is to generate a few more variables and do a data check before saveing a file to export to supply side;

// make tax_coeff negative because of the way we use it.
replace tax_coeff=tax_coeff*-1
replace tax_coeff100=tax_coeff100*-1

// replace variables for other modes
replace density1=0 if mode~=1
replace am_share=1 if mode~=1

// calculate the value of alpha (preferences for each mode)
gen alpha=delta+mode_fe-(1-tax_coeff-tax_coeff100*perc_100)*(log(1+am_share*tax_status*tax_rate)-log(1+tax_rate))-density_coeff*density1 if mode==1
replace alpha=delta+mode_fe-(1-tax_coeff-tax_coeff100*perc_100)*(log(1+tax_status*tax_rate)-log(1+tax_rate))-density_coeff*density1 if mode~=1

// save a main data set
save "ces_data.dta", replace

keep year county mode nb_hh avg_spending_annual_county alpha tax_rate tax_status density1 perc_100 tax_coeff tax_coeff100 density_coeff am_share margin0 prods_per pre_laprice1 pre_lmprice1 pre_liquart1 pre_lstd1 mode_fe loc_pref ave_tran_price_w1 median_price_w1 iquart_w1 stdev_tran_price_w1

// replace perc_100 so that we don't have any elasticities less than 1
replace perc_100=.35 if perc_100>.35

// predict lhs of the regression.
gen pre_dep=exp(alpha+(1-tax_coeff-tax_coeff100*perc_100)*(log(1+am_share*tax_status*tax_rate)-log(1+tax_rate))+density_coeff*density1) if mode==1
replace pre_dep=exp(alpha+(1-tax_coeff-tax_coeff100*perc_100)*(log(1+tax_status*tax_rate)-log(1+tax_rate))+density_coeff*density1) if mode~=1

// predict lhs of regression for each mode
gen pre_dep1_tmp=pre_dep if mode==1
egen pre_dep_1=max(pre_dep1_tmp), by(county year)
replace pre_dep_1=0 if pre_dep_1==.

gen pre_dep2_tmp=pre_dep if mode==2
egen pre_dep_2=max(pre_dep2_tmp), by(county year)
replace pre_dep_2=0 if pre_dep_2==.

gen pre_dep3_tmp=pre_dep if mode==3
egen pre_dep_3=max(pre_dep3_tmp), by(county year)
replace pre_dep_3=0 if pre_dep_3==.

// calculate expenditures for each mode
gen pred0=(avg_spending_annual_county)/(1+pre_dep_1+pre_dep_2+pre_dep_3)
gen pred1=pre_dep_1*pred0
gen pred2=pre_dep_2*pred0
gen pred3=pre_dep_3*pred0

// adjust expenditures so it is net of taxes.
gen pre_exp=pred1*1/(1+tax_status*tax_rate*am_share)   if mode==1
replace pre_exp=pred2*1/(1+tax_rate) if mode==2
replace pre_exp=pred3 if mode==3

gen pre_exp2=pred1*1/(1+tax_status*tax_rate*am_share) if mode==1
replace pre_exp2=pred2*1/(1+tax_rate) if mode==2
replace pre_exp2=pred3 if mode==3

gen pre_exp3=pred1 if mode==1
replace pre_exp3=pred2 if mode==2
replace pre_exp3=pred3 if mode==3

// generate offline expenitures
egen exp_tmp=sum(pre_exp), by(county year)
gen off_pre_exp=(avg_spending_annual_county)-exp_tmp

// blow up to get the county level expenditures.
gen pre_exp_county=pre_exp*nb_hh
gen pre_exp_county2=pre_exp2*nb_hh
gen pre_exp_county3=pre_exp3*nb_hh
egen tot_exp=sum(pre_exp_county), by(year mode)
egen tot_exp2=sum(pre_exp_county2), by(year mode)
egen tot_exp3=sum(pre_exp_county3), by(year mode)

// total households.
egen tot_hh=sum(nb_hh), by(year mode)

// formate large variables so we can observe them without scientific notation. Use this for a check. 
format tot_exp %15.3g
format tot_exp2 %15.3g
format tot_exp3 %15.3g

// amazon's marging and margin on 3rd party sales
gen a_margin=.15
gen mp_margin=.30

// outsheet data set for supply side. 
order year county mode nb_hh avg_spending_annual_county alpha tax_rate tax_status density1 perc_100 tax_coeff tax_coeff100 density_coeff am_share margin0 prods_per pre_laprice1 pre_lmprice1 pre_liquart1 pre_lstd1 a_margin mp_margin
outsheet year county mode nb_hh avg_spending_annual_county alpha tax_rate tax_status density1 perc_100 tax_coeff tax_coeff100 density_coeff am_share margin0 prods_per pre_laprice1 pre_lmprice1 pre_liquart1 pre_lstd1 a_margin mp_margin using "ces_data`model'.csv", comma names replace


