capture log close
set more off
clear
// Project: Nexus Tax Laws and Economies of Density in E-Commerce: A Study of Amazon’s Fulfillment Center Network
// Authors: Houde, Newberry, Seim
// Created by: Peter Newberry
// Date: 05/2022
// Description: Creates Figure 2 in the paper.
// Data sets needed: spending_data_summary2.dta: county level spending. Prorpetary due to aggreement with comScore.
//                   cb_2013_us_county_500k/cb_2013_us_county_500k: county shape file downloaded from https://www.census.gov/geographies/mapping-files/2013/geo/carto-boundary-file.html
// Author notes: based on author do-file "spending_data_summary.do"

******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
//Create US map with county level spending (top of figure 2)

// Import spending data and keep just 2016 data
use "spending_data_summary2.dta", clear
contract county exp_county_forr year
keep if year==2016
drop  _freq
contract county exp_county_forr 
save "tmp_spending2.dta", replace

// Import shape file and merge in spending data
shp2dta using "cb_2013_us_county_500k", database(st_data) coordinates(st_coordinates) genid(id) replace
use st_data, clear
gen county= STATEFP+ COUNTYFP
destring county, replace
merge 1:m county using "tmp_spending2.dta"
keep if _merge==3

// Create county level map with spending from 2016
spmap exp_county_forr using "st_coordinates.dta", fcolor(Blues) id(id) clnumber(5) legstyle(3) legtitle("Household Spending on Amazon") 
graph export "map_spending_dist.png", replace  width(800)


******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
// Generate statistics on average spending across different demographic groups/regions (bottom of Figure 2)


// Import spending data
use "spending_data_summary2.dta", clear
gen urban=pop_density>500 //urban dummy
gen wealthy=mean_income>80000 //wealthy dummy

//create total spending across different demos and regions.
egen tot_spend_popdens=sum(nb_hh*exp_county_forr), by(year urban)
egen tot_spend_income=sum(nb_hh*exp_county_forr), by(year wealthy)
egen tot_spend_region=sum(nb_hh*exp_county_forr), by(year region)

// create total households across different demos and regions.
egen tot_hh_popdens=sum(nb_hh*(exp_county_forr~=.)), by(year urban)
egen tot_hh_income=sum(nb_hh*(exp_county_forr~=.)), by(year wealthy)
egen tot_hh_region=sum(nb_hh*(exp_county_forr~=.)), by(year region)


// create average spending across different demos and regions.
preserve
contract tot_spend_popdens year urban tot_hh_popdens
keep if urban==1
gen ave_spend_urban=tot_spend_popdens/tot_hh_popdens
save "spending_tmp1.dta", replace
restore

preserve
contract tot_spend_popdens year urban tot_hh_popdens
keep if urban==0
gen ave_spend_rural=tot_spend_popdens/tot_hh_popdens
save "spending_tmp2.dta", replace
restore

preserve
contract tot_spend_income year wealthy tot_hh_income
keep if  wealthy==1
gen ave_spend_wealthy=tot_spend_income/tot_hh_income
save "spending_tmp3.dta", replace
restore

preserve
contract tot_spend_income year wealthy tot_hh_income
keep if  wealthy==0
gen ave_spend_poor=tot_spend_income/tot_hh_income
save "spending_tmp4.dta", replace
restore

preserve
contract tot_spend_region year region  tot_hh_region
keep if  region==1
gen ave_spend_region1=tot_spend_region/tot_hh_region
save "spending_tmp5.dta", replace
restore

preserve
contract tot_spend_region year region tot_hh_region
keep if  region==2
gen ave_spend_region2=tot_spend_region/tot_hh_region
save "spending_tmp6.dta", replace
restore

preserve
contract tot_spend_region year region tot_hh_region
keep if  region==3
gen ave_spend_region3=tot_spend_region/tot_hh_region
save "spending_tmp7.dta", replace
restore

preserve
contract tot_spend_region year region tot_hh_region
keep if  region==4
gen ave_spend_region4=tot_spend_region/tot_hh_region
save "spending_tmp8.dta", replace
restore

// append spending data together.
use "spending_tmp1.dta", clear
merge 1:1 year using "spending_tmp2.dta"
drop _merge
merge 1:1 year using "spending_tmp3.dta"
drop _merge
merge 1:1 year using "spending_tmp4.dta"
drop _merge
merge 1:1 year using "spending_tmp5.dta"
drop _merge
merge 1:1 year using "spending_tmp6.dta"
drop _merge
merge 1:1 year using "spending_tmp7.dta"
drop _merge
merge 1:1 year using "spending_tmp8.dta"
drop _merge

keep year ave_spend*

// create table. put year=2016 into figure 2 in the paper
outsheet year ave_spend* using "spending_data_summary_het.csv", replace comma names
