capture log close
set more off
clear
// Project: Nexus Tax Laws and Economies of Density in E-Commerce: A Study of Amazon’s Fulfillment Center Network
// Authors: Houde, Newberry, Seim
// Created by: Peter Newberry
// Date: 05/2022
// Description: Creates Figure 3 in the paper
// Data sets needed: facility_panel.dta: panel of facility/year data created by authors.
//                   state_statistics.dta: demographics, etc., created by authors.
//                   cb_2013_us_state_500k: state shape file from https://www.census.gov/geographies/mapping-files/2013/geo/carto-boundary-file.html
// Author notes: based on author do-file "expansion_tables_mpa.do"

******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
// Create figure 3

use "facility_panel.dta", clear

// Kepp only faclities that are active.
drop if facility_active==0 

//Generate the points indicating FCs on the map in 1999-2018
preserve
keep if year==1999
keep if fc==1
rename loc_fc num_fac
contract cluster_id num_fac cluster_lat cluster_lng
drop _freq
gen fc_ind=0
save "locs1999.dta", replace
restore

forvalues y=0/9 {
preserve
keep if year==200`y'
keep if fc==1
rename loc_fc num_fac
contract cluster_id num_fac cluster_lat cluster_lng
drop _freq
gen fc_ind=0
save "locs200`y'.dta", replace
restore
}

forvalues y=10/18 {
preserve
keep if year==20`y'
keep if fc==1
rename loc_fc num_fac
contract cluster_id num_fac cluster_lat cluster_lng
drop _freq
gen fc_ind=0
save "locs20`y'.dta", replace
restore
}


//Generate the points indicating SCs on the map in 2011-2018
forvalues y=11/18 {
preserve
keep if year==20`y'
keep if fc==0
rename loc_sc num_fac
contract cluster_id num_fac cluster_lat cluster_lng
replace num_fac=.3 if num_fac>0
drop _freq
gen fc_ind=1
append using "locs20`y'.dta"

replace num_fac=1 if fc_ind==1
replace num_fac=num_fac+2 if fc_ind==0
save "locs20`y'.dta", replace
restore
}

// Create state statistic files at the year level.
use "state_statistics.dta", clear

preserve
keep if year==1999
save "tax1999.dta", replace
restore

forvalues y=0/9 {
preserve
keep if year==200`y'
save "tax200`y'.dta", replace
restore
}

forvalues y=10/19 {
preserve
keep if year==20`y'
save "tax20`y'.dta", replace
restore
}

// Import state shape file.
shp2dta using "cb_2013_us_state_500k", database(st_data) coordinates(st_coordinates) genid(id) replace

use st_data, clear
rename STUSPS state
sort state

// Merge lat/lngs and tax info
merge 1:m state using "state_statistics.dta"


// Create mapes for each year
spmap state_hh using "st_coordinates.dta" if year==1999, legend(label(2 "2.3-7.5") label(3 "7.5-17.5") label(4 "17.5-27.3") label(5 "27.3-130.2")) clmethod(custom) clbreaks(0 7.5 17.5 27.3 130.2) legend(on) fcolor(Blues) id(id)  legtitle("Households (100k)") legstyle(1) point(data("locs1999.dta") by(fc_ind) x(cluster_lng) y(cluster_lat) proportional(num_fac) size(2.75 2.75) ocolor(black) osize(medium) fcolor(red)) label(data("tax1999.dta") x(state_lon) y(state_lat) label(ave_tax)  size(3))  
graph export "FC_locs99_color.png", replace

forvalues y=0/9 {
spmap state_hh using "st_coordinates.dta" if year==200`y', legend(label(2 "2.3-7.5") label(3 "7.5-17.5") label(4 "17.5-27.3") label(5 "27.3-130.2")) clmethod(custom) clbreaks(0 7.5 17.5 27.3 130.2) legend(on) fcolor(Blues) id(id)  legtitle("Households (100k)") legstyle(1) point(data("locs200`y'.dta") by(fc_ind) x(cluster_lng) y(cluster_lat) proportional(num_fac) size(2.75 2.75) ocolor(black) osize(medium) fcolor(red)) label(data("tax200`y'.dta") x(state_lon) y(state_lat) label(ave_tax)  size(3))  
graph export "FC_locs0`y'_color.png", replace
}

spmap state_hh using "st_coordinates.dta" if year==2010, legend(label(2 "2.3-7.5") label(3 "7.5-17.5") label(4 "17.5-27.3") label(5 "27.3-130.2")) clmethod(custom) clbreaks(0 7.5 17.5 27.3 130.2) legend(on) fcolor(Blues) id(id)  legtitle("Households (100k)") legstyle(1) point(data("locs2010.dta") by(fc_ind) x(cluster_lng) y(cluster_lat) proportional(num_fac) size(2.75 2.75) ocolor(black) osize(medium) fcolor(red)) label(data("tax2010.dta") x(state_lon) y(state_lat) label(ave_tax)  size(3))  
graph export "FC_locs10_color.png", replace

forvalues y=11/18 {
spmap state_hh using "st_coordinates.dta" if year==20`y', legend(label(2 "2.3-7.5") label(3 "7.5-17.5") label(4 "17.5-27.3") label(5 "27.3-130.3")) clmethod(custom) clbreaks(0 7.5 17.5 27.3 130.3) legend(on) fcolor(Blues) id(id)  legtitle("Households (100k)") legstyle(1) point(data("locs20`y'.dta") by(fc_ind) x(cluster_lng) y(cluster_lat) proportional(num_fac) size(medlarge medlarge) ocolor(black black) osize(medium medium) fcolor(red yellow)) label(data("tax20`y'.dta") x(state_lon) y(state_lat) label(ave_tax)  size(3))  
graph export "FC_locs`y'_color.png", replace
}


