capture log close
set more off
clear
// Project: Nexus Tax Laws and Economies of Density in E-Commerce: A Study of Amazon’s Fulfillment Center Network
// Authors: Houde, Newberry, Seim
// Created by: Peter Newberry
// Date: 05/2022
// Description: Creates Tables 1 and 2 in the paper.
// Data sets needed: facility_panel.dta: panel of facility/year data created by authors.
//                   county_panel.dta: county demographics, etc., created by authors
// 					 aggregate_financials.dta: has financial data for Amazon.
// Author notes: based on author do-file "expansion_tables_mpa.do"

******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
// Create table 1

use "facility_panel.dta", clear

// Keep only active facilities
drop if facility_active==0 

//Create total number of FCs and SCs and locations.
egen tot_FC=sum(fc), by(year) 
egen tot_SC=sum(sc), by(year)
egen tot_locs=nvals(cluster_id), by(year)

//Create total number of locations with FCs and SCs
egen tot_locs_type=nvals(cluster_id), by(year fc)
gen temp=tot_locs_type if fc==1
gen temp2=tot_locs_type if fc==0
egen tot_locsFC=max(temp), by(year)
egen tot_locsSC=max(temp2), by(year)
drop temp*

//Create total square footage by facility type.
egen tot_FC_size=sum(facility_size*fc), by(year)
egen tot_SC_size=sum(facility_size*sc), by(year)

//Create average size of location by type
gen ave_FCloc_size=tot_FC_size/100000/tot_locsFC
gen ave_SCloc_size=tot_SC_size/100000/tot_locsSC

//Create average size of facility by type
gen ave_FC_size=tot_FC_size/100000/tot_FC
gen ave_SC_size=tot_SC_size/100000/tot_SC

//Create number of states with facility
egen states_wfacility=nvals(state), by(year)

//Contract to year level
contract year tot_FC tot_SC tot_locs ave_FCloc_size ave_SCloc_size states_wfacility
drop _freq

//Merge in to get aggregate employment data.
merge 1:1 year using "aggregate_financials.dta"
drop _merge

//Create average employment
gen ave_employ=labor_distribution/tot_loc

//Save temporary file.
save "temp.dta", replace


//Create variables about availability of SC and distance using the demographic panel
use "county_panel.dta", clear
egen state_hh=sum(nb_hh), by(year)
egen ave_dist=sum(nb_hh*min_dist/state_hh), by(year)
egen perc_sc=sum(nb_hh*sc_available/state_hh), by(year)
contract year perc_sc ave_dist
drop _freq
merge 1:1 year using "temp.dta"
drop _merge

//Create information that goes into Table 1. 
outsheet year tot_FC tot_SC tot_locs ave_FCloc_size ave_SCloc_size ave_employ ave_dist states_wfacility perc_sc using "table1.csv", comma names replace



******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
******************************************************************************
// Create table 2
use "county_panel.dta", clear

// Merge in FC/SC presence info in each county/year.
merge 1:1 county year using "county_presence_panel.dta"
replace tot_fc_county=0 if tot_fc_county==.
replace tot_sc_county=0 if tot_sc_county==.

drop _merge

// Merge in year Amazon started collecting taxes in each state. 
rename state state_full
rename state_abbrev state
merge m:1 state using "state_tax_dates.dta"

gen taxed=year>=tax_year

// Caclulate ave tax rate in each state. 
rename nb_hh households
egen tot_hh_state=sum(households), by(state year)
egen state_tax_rate=sum(households*tax/tot_hh_state), by(state year)

// Presence dummy
gen county_presence=(tot_fc_county+tot_sc_county)>0


keep county year state households tax imputed_wage county_rent_dis_imputed pop_density  county_presence state_tax_rate taxed


egen tot_presence=sum(county_presence), by(year)

gen dum=1
egen tot_county=sum(dum), by(year)

// Caculate statistics for counties that have a presence and those that don't.

egen ave_households_presence=sum(county_presence*households/tot_presence), by(year)
egen ave_households=sum(households/tot_county), by(year)

egen ave_wage_presence=sum(county_presence*imputed_wage/tot_presence), by(year)
egen ave_wage=sum(imputed_wage/tot_county), by(year)

egen ave_rent_presence=sum(county_presence*county_rent_dis_imputed/tot_presence), by(year)
egen ave_rent=sum(county_rent_dis_imputed/tot_county), by(year)

egen ave_dens_presence=sum(county_presence*pop_density/tot_presence), by(year)
egen ave_dens=sum(pop_density/tot_county), by(year)


// Calculate average sales tax in states with and without a presence. Do this at the state level rather than county.
preserve
egen state_presence=max(county_presence), by(state year)
contract state year state_presence state_tax_rate
drop _freq
gen dum=1
egen tot_state=sum(dum), by(year)
egen tot_presence=sum(state_presence), by(year)

egen ave_tax_presence=sum(state_presence*state_tax_rate/tot_presence), by(year)
egen ave_tax=sum(state_tax_rate/tot_state), by(year)

contract ave_tax_presence year ave_tax
save "temp.dta", replace
restore

// Merge in tax data.
merge m:1 year using "temp.dta"
drop _merge

drop _freq	
erase "temp.dta"

// Generate the percentage of households taxed.
egen tot_hh=sum(households), by(year)
egen perc_taxed=sum(households*taxed/tot_hh), by(year)


contract year ave_* perc_taxed
drop _freq
drop if year==.
// save information for table 2
outsheet using "table2.csv", comma names replace
