capture log close
set more off
clear
// Project: Nexus Tax Laws and Economies of Density in E-Commerce: A Study of Amazon’s Fulfillment Center Network
// Authors: Houde, Newberry, Seim
// Created by: Peter Newberry
// Date: 05/2022
// Description: Creates Table 10 
// Data sets needed: Cluster_panel_threshold20.dta
//  `				 Network_simulation_year1999_taxdelay1.dta: simulation results from the ox code. 
//					 Regional_CPI.xlsx: CPI information from the BLS 
//					 cbsa2fipsxw.dta: crosswalk of cbsa to county fips from U of Missouri. 
//					 ces_data2.dta: data created from the demand model
//					 demo_panel_final_mode.dta: county demographics, etc., created by authors. Just county_panel repeated three times...once for each mode.
// 					 State_census_codes.dta: FIPS codes for each state as well as Census region and district for each state. Available from Census. 
// Author notes: based on author do-file "cv_calc.do" and "tax_rev_calc.do"
*********************************************************
*********************************************************
*********************************************************
*********************************************************
*********************************************************
*********************************************************
*********************************************************

//first part creates the locations of the facilities in the "base case"


//get information for each cluster
use "Cluster_panel_threshold20.dta", clear
contract cluster_id county_code state_code
drop _freq
save "cluster_info.dta", replace

//import information for each simulation year for the observed network
use "Network_simulation_year1999_taxdelay1.dta", clear
format total_profit %20.0g
replace total_profit=-1*total_profit
sort cluster_id total_profit sim
egen prof_rank=rank(total_profit), by(cluster_id) unique 
keep if prof_rank==1
keep cluster_id nb_fc nb_sc
format cluster_id %5.0g
format nb_sc %5.0g
format nb_fc %5.0g
merge 1:m cluster_id using "cluster_info.dta"
gen year=1999
save "base_net99.dta", replace


use "Network_simulation_year2006_taxdelay1.dta", clear
format total_profit %20.0g
replace total_profit=-1*total_profit
sort cluster_id total_profit sim
egen prof_rank=rank(total_profit), by(cluster_id) unique 
keep if prof_rank==1
keep cluster_id nb_fc nb_sc
format cluster_id %5.0g
format nb_sc %5.0g
format nb_fc %5.0g
merge 1:m cluster_id using "cluster_info.dta"
gen year=2006
save "base_net06.dta", replace


use "Network_simulation_year2012_taxdelay1.dta", clear
format total_profit %20.0g
replace total_profit=-1*total_profit
sort cluster_id total_profit sim
egen prof_rank=rank(total_profit), by(cluster_id) unique 
keep if prof_rank==1
keep cluster_id nb_fc nb_sc
format cluster_id %5.0g
format nb_sc %5.0g
format nb_fc %5.0g
merge 1:m cluster_id using "cluster_info.dta"
gen year=2012
save "base_net12.dta", replace


use "Network_simulation_year2018_taxdelay1.dta", clear
format total_profit %20.0g
replace total_profit=-1*total_profit
sort cluster_id total_profit sim
egen prof_rank=rank(total_profit), by(cluster_id) unique 
keep if prof_rank==1
keep cluster_id nb_fc nb_sc
format cluster_id %5.0g
format nb_sc %5.0g
format nb_fc %5.0g
merge 1:m cluster_id using "cluster_info.dta"
gen year=2018

append using "base_net99.dta"
append using "base_net06.dta"
append using "base_net12.dta"
drop _merge
rename county_code county

//save file for the network under the observed (network) laws
save "base_net.dta", replace

*********************************************************
*********************************************************
*********************************************************
*********************************************************
*********************************************************
*********************************************************
*********************************************************

//second part caclulates the compensating variaion


//import CPI information 
import excel "Regional_CPI.xlsx", sheet("Regional CPI (cleaned)") cellrange(A1:U24) firstrow  clear
rename Regions cbsatitle
merge 1:m cbsatitle using "cbsa2fipsxw.dta"
keep if _merge==3
keep fipsstatecode fipscountycode CPI1999-CPI2018
gen fipscountycode2=fipsstatecode + fipscountycode
destring fipscountycode2, replace
rename fipscountycode2 county
keep county CPI1999-CPI2018 
order county CPI1999-CPI2018 
reshape long CPI, i(county) j(year)
rename CPI cpi1
save "countyCPI.dta", replace

import excel "Regional_CPI.xlsx", sheet("Regional CPI (cleaned) 2") cellrange(A1:X22) firstrow clear
keep if Size==. & DivisionNumber==.
keep RegionNumber CPI1999-CPI2018	
rename RegionNumber region
reshape long CPI, i(region) j(year)
rename CPI cpi2
save "regionCPI.dta", replace

import excel "Regional_CPI.xlsx", sheet("Regional CPI (cleaned) 2") cellrange(A1:X22) firstrow clear
keep if Size~=. & DivisionNumber==.
keep RegionNumber  Size CPI1999-CPI2018	
rename RegionNumber region
rename Size large_county
reshape long CPI, i(region large_county) j(year)
rename CPI cpi3
save "regionsizeCPI.dta", replace

import excel "Regional_CPI.xlsx", sheet("Regional CPI (cleaned) 2") cellrange(A1:X22) firstrow clear
keep if DivisionNumber~=.
keep DivisionNumber CPI1999-CPI2018	
rename DivisionNumber district
reshape long CPI, i(district) j(year)
rename CPI cpi4
save "districtCPI.dta", replace


// bring in spending data and demand model params
insheet using "ces_data2.csv", clear comma names 
rename tax_status tax_status_obs

keep year county mode nb_hh avg_spending_annual_county alpha tax_rate ///
tax_status_obs perc_100 tax_coeff tax_coeff100 pre_laprice1

merge m:1 county year using "base_net.dta"
drop if _merge==2
drop _merge
replace nb_fc=0 if nb_fc==.
replace nb_sc=0 if nb_sc==.


gen tax_status_base=(nb_fc>0 | nb_sc>0) if mode==1
drop cluster_id nb_fc nb_sc

// get county and state fips
tostring county, gen(county_str)
gen state_str=substr(county_str, 1, 1) if strlen(county_str)==4
replace state_str=substr(county_str, 1, 2) if strlen(county_str)==5
destring state_str, gen(state_id)
drop county_str
drop state_str

// generate tax statuses under different regimes
egen tax_status_base2=max(tax_status_base), by(state_id year mode)
replace tax_status_base=tax_status_base2
drop tax_status_base2

replace tax_status_base=1 if mode==2
replace tax_status_base=0 if mode==3

gen tax_status_all=1  if mode==1
replace tax_status_all=1 if mode==2
replace tax_status_all=0 if mode==3

summ pre_laprice1 if mode==2 & year==2006

// generate prices at walmart
gen US_cpi2006=208.1/(1+0.063)
gen wm_base_price=`r(mean)'/US_cpi2006


// Merge in demographics for consumers.
sort county year mode
merge county year mode using "demo_panel_final_mode.dta"
tab _merge
drop _merge

// Merge in state FIPS codes as well as Census region district.
replace state=trim(state)
sort state
merge m:1 state using "State_census_codes.dta"
keep if _merge==3
drop _merge

rename state state2
rename state_abbrev state

rename census_region region
rename census_division district


drop fips-tax1

// merge in CPI information.
gen large_county=(nb_hh>=20000) /*found defintion here https://www.investopedia.com/terms/a/abcd-counties.asp for ABCD counties*/

merge m:1 county year using "countyCPI.dta"
drop if _merge==2
drop _merge

merge m:1 region year using "regionCPI.dta"
drop if _merge==2
drop _merge

merge m:1 region year large_county using "regionsizeCPI.dta"
drop if _merge==2
drop _merge

merge m:1 district year using "districtCPI.dta"
drop if _merge==2
drop _merge

// gerneate offline prices based on different measures of price index.
gen offline_price1=cpi1*wm_base_price/(1+tax_rate)
gen offline_price2=cpi2*wm_base_price/(1+tax_rate)
gen offline_price3=cpi3*wm_base_price/(1+tax_rate)
gen offline_price4=cpi4*wm_base_price/(1+tax_rate)

gen offline_price=offline_price1
replace offline_price=(offline_price3+offline_price4)/2 if offline_price==.
replace offline_price=offline_price

//reshape data seat to get in correct format.
keep year-alpha2 tax_status_base tax_status_all offline_price tax_status_obs
rename alpha2 alpha

rename pre_laprice1 price

reshape wide alpha price tax_status_base tax_status_all tax_status_obs, i(year county nb_hh avg_spending_annual_county perc_100 tax_coeff tax_coeff100 offline_price) j(mode)

order county year alpha* tax_status_base* tax_status_all* price* offline_price nb_hh perc_100 avg_spending_annual_county tax_coeff tax_coeff100  tax_rate
keep if year==1999 | year==2006 | year==2012 | year==2018

// calculate sigma
gen sigma=(tax_coeff+tax_coeff100*perc_100)

//calculate compensating variation. refer to online appendix for formulas.
gen e_alpha1=exp(alpha1-(1-sigma)*(log(price1/(1+tax_status_obs1*tax_rate))-log(offline_price/(1+tax_rate))))
gen e_alpha2=exp(alpha2-(1-sigma)*(log(price2/(1+tax_status_obs2*tax_rate))-log(offline_price/(1+tax_rate))))
gen e_alpha3=exp(alpha3-(1-sigma)*(log(price3/(1+tax_status_obs3*tax_rate))-log(offline_price/(1+tax_rate))))

gen cons0=(e_alpha1*(price1*(1+tax_status_base1*tax_rate))^(1-sigma)+e_alpha2*(price2*(1+tax_status_base2*tax_rate))^(1-sigma)+e_alpha3*(price3*(1+tax_status_base3*tax_rate))^(1-sigma)+offline_price^(1-sigma))^(sigma/(sigma-1))
gen cons1=(e_alpha1*(price1*(1+tax_status_all1*tax_rate))^(1-sigma)+e_alpha2*(price2*(1+tax_status_all2*tax_rate))^(1-sigma)+e_alpha3*(price3*(1+tax_status_all3*tax_rate))^(1-sigma)+offline_price^(1-sigma))^(sigma/(sigma-1))

gen pind0=1/(e_alpha1*(price1*(1+tax_status_base1*tax_rate))^(1-sigma)+e_alpha2*(price2*(1+tax_status_base2*tax_rate))^(1-sigma)+e_alpha3*(price3*(1+tax_status_base3*tax_rate))^(1-sigma)+offline_price^(1-sigma))
gen pind1=1/(e_alpha1*(price1*(1+tax_status_all1*tax_rate))^(1-sigma)+e_alpha2*(price2*(1+tax_status_all2*tax_rate))^(1-sigma)+e_alpha3*(price3*(1+tax_status_all3*tax_rate))^(1-sigma)+offline_price^(1-sigma))


gen b_star=avg_spending_annual_county*cons0*pind0/(cons1*pind1)
gen cv_ind=b_star-avg_spending_annual_county

egen cons_w=sum(nb_hh*(cv_ind)/1000000), by(year)
contract cons_w year

// save information. This is hand copied into table 10.
outsheet using "cv_calc.csv", comma nonames replace

*********************************************************
*********************************************************
*********************************************************
*********************************************************
*********************************************************
*********************************************************
*********************************************************

//third part calculates revenue, tax revenue and other things needed for table 10.

// bring in spending data and demand model params
insheet using "ces_data2.csv", clear comma names 
rename tax_status tax_status_obs

keep year county mode nb_hh avg_spending_annual_county alpha tax_rate ///
tax_status_obs perc_100 tax_coeff tax_coeff100 pre_laprice1

merge m:1 county year using "base_net.dta"
drop if _merge==2
drop _merge
replace nb_fc=0 if nb_fc==.
replace nb_sc=0 if nb_sc==.


gen tax_status_base=(nb_fc>0 | nb_sc>0) if mode==1
drop cluster_id nb_fc nb_sc

// get county and state fips
tostring county, gen(county_str)
gen state_str=substr(county_str, 1, 1) if strlen(county_str)==4
replace state_str=substr(county_str, 1, 2) if strlen(county_str)==5
destring state_str, gen(state_id)
drop county_str
drop state_str

// generate tax statuses under different regimes
egen tax_status_base2=max(tax_status_base), by(state_id year mode)
replace tax_status_base=tax_status_base2
drop tax_status_base2

replace tax_status_base=1 if mode==2
replace tax_status_base=0 if mode==3

gen tax_status_all=1  if mode==1
replace tax_status_all=1 if mode==2
replace tax_status_all=0 if mode==3

// use model to predict spending.
gen delta=alpha2+(1-tax_coeff-tax_coeff100*perc_100)*(log(1+tax_status_obs*tax_rate)-log(1+tax_rate))

/*predict actual exp*/
gen pre_dep=exp(delta) 

gen pre_dep1_tmp=pre_dep if mode==1
egen pre_dep_1=max(pre_dep1_tmp), by(county year)
replace pre_dep_1=0 if pre_dep_1==.

gen pre_dep2_tmp=pre_dep if mode==2
egen pre_dep_2=max(pre_dep2_tmp), by(county year)
replace pre_dep_2=0 if pre_dep_2==.

gen pre_dep3_tmp=pre_dep if mode==3
egen pre_dep_3=max(pre_dep3_tmp), by(county year)
replace pre_dep_3=0 if pre_dep_3==.

gen pred0=(avg_spending_annual_county)/(1+pre_dep_1+pre_dep_2+pre_dep_3)
gen pred1=pre_dep_1*pred0
gen pred2=pre_dep_2*pred0
gen pred3=pre_dep_3*pred0

gen pre_exp=pred1*1/(1+tax_status_obs*tax_rate) if mode==1
replace pre_exp=pred2*1/(1+tax_status_obs*tax_rate) if mode==2
replace pre_exp=pred3 if mode==3


gen pre_exp2=pred1 if mode==1
replace pre_exp2=pred2 if mode==2
replace pre_exp2=pred3 if mode==3
 
// calculate offline expenditures.
egen exp_tmp=sum(pre_exp2), by(county year)
gen off_pre_exp=((avg_spending_annual_county)-exp_tmp)/(1+tax_rate)
*drop *_tmp

// blow up spending to county.
gen pre_exp_county=pre_exp*nb_hh
egen tot_exp=sum(pre_exp_county), by(year mode)
egen tot_exp_off=sum(off_pre_exp*(mode==1)*nb_hh), by(year)

gen tax_rev_county=pre_exp_county*(tax_status_obs*tax_rate) if mode==1
replace tax_rev_county=pre_exp_county*tax_status_obs*tax_rate if mode==2
replace tax_rev_county=0 if mode==3
gen tax_rev_county_off=off_pre_exp*tax_rate

egen tot_tax_rev=sum(tax_rev_county), by(year mode)
egen tot_tax_rev_off=sum(tax_rev_county_off*(mode==1)*nb_hh), by(year)

egen tot_hh=sum(nb_hh*(pre_exp~=.)), by(year mode)

format tot_exp %15.5g
format tot_hh %15.5g


// predict expenditures with non-discriminatory taxes.
gen delta_all=alpha2+(1-tax_coeff-tax_coeff100*perc_100)*(log(1+tax_status_all*tax_rate)-log(1+tax_rate))

drop pre_dep*
drop pred*
drop pre_exp pre_exp2
drop exp_tmp
gen pre_dep=exp(delta_all) 

gen pre_dep1_tmp=pre_dep if mode==1
egen pre_dep_1=max(pre_dep1_tmp), by(county year)
replace pre_dep_1=0 if pre_dep_1==.

gen pre_dep2_tmp=pre_dep if mode==2
egen pre_dep_2=max(pre_dep2_tmp), by(county year)
replace pre_dep_2=0 if pre_dep_2==.

gen pre_dep3_tmp=pre_dep if mode==3
egen pre_dep_3=max(pre_dep3_tmp), by(county year)
replace pre_dep_3=0 if pre_dep_3==.

gen pred0=(avg_spending_annual_county)/(1+pre_dep_1+pre_dep_2+pre_dep_3)
gen pred1=pre_dep_1*pred0
gen pred2=pre_dep_2*pred0
gen pred3=pre_dep_3*pred0

gen pre_exp=pred1*1/(1+tax_status_all*tax_rate) if mode==1
replace pre_exp=pred2*1/(1+tax_status_all*tax_rate) if mode==2
replace pre_exp=pred3 if mode==3

gen pre_exp2=pred1 if mode==1
replace pre_exp2=pred2 if mode==2
replace pre_exp2=pred3 if mode==3

egen exp_tmp=sum(pre_exp2), by(county year)
gen off_pre_exp_all=((avg_spending_annual_county)-exp_tmp)/(1+tax_rate)
*drop *_tmp

gen pre_exp_county_all=pre_exp*nb_hh
egen tot_exp_all=sum(pre_exp_county_all), by(year mode)
egen tot_exp_all_off=sum(off_pre_exp_all*(mode==1)*nb_hh), by(year)

gen tax_rev_county_all=pre_exp_county_all*(tax_status_all*tax_rate) if mode==1
replace tax_rev_county_all=pre_exp_county_all*tax_status_all*tax_rate if mode==2
replace tax_rev_county_all=0 if mode==3
gen tax_rev_county_all_off=off_pre_exp_all*tax_rate

egen tot_tax_rev_all=sum(tax_rev_county_all), by(year mode)
egen tot_tax_rev_all_off=sum(tax_rev_county_all_off*(mode==1)*nb_hh), by(year)


format tot_exp_all %15.5g

// predict expenditures in base case in the counterfactual (not the same as observed)
gen delta_base=alpha2+(1-tax_coeff-tax_coeff100*perc_100)*(log(1+tax_status_base*tax_rate)-log(1+tax_rate))

drop pre_dep*
drop pred*
drop pre_exp pre_exp2
drop exp_tmp
gen pre_dep=exp(delta_base) 

gen pre_dep1_tmp=pre_dep if mode==1
egen pre_dep_1=max(pre_dep1_tmp), by(county year)
replace pre_dep_1=0 if pre_dep_1==.

gen pre_dep2_tmp=pre_dep if mode==2
egen pre_dep_2=max(pre_dep2_tmp), by(county year)
replace pre_dep_2=0 if pre_dep_2==.

gen pre_dep3_tmp=pre_dep if mode==3
egen pre_dep_3=max(pre_dep3_tmp), by(county year)
replace pre_dep_3=0 if pre_dep_3==.

gen pred0=(avg_spending_annual_county)/(1+pre_dep_1+pre_dep_2+pre_dep_3)
gen pred1=pre_dep_1*pred0
gen pred2=pre_dep_2*pred0
gen pred3=pre_dep_3*pred0

gen pre_exp=pred1*1/(1+tax_status_base*tax_rate) if mode==1
replace pre_exp=pred2*1/(1+tax_status_base*tax_rate) if mode==2
replace pre_exp=pred3 if mode==3

gen pre_exp2=pred1 if mode==1
replace pre_exp2=pred2 if mode==2
replace pre_exp2=pred3 if mode==3

egen exp_tmp=sum(pre_exp2), by(county year)
gen off_pre_exp_base=((avg_spending_annual_county)-exp_tmp)/(1+tax_rate)

gen pre_exp_county_base=pre_exp*nb_hh
egen tot_exp_base=sum(pre_exp_county_base), by(year mode)
egen tot_exp_base_off=sum(off_pre_exp_base*(mode==1)*nb_hh), by(year)

gen tax_rev_county_base=pre_exp_county_base*(tax_status_base*tax_rate) if mode==1
replace tax_rev_county_base=pre_exp_county_base*tax_status_base*tax_rate if mode==2
replace tax_rev_county_base=0 if mode==3
gen tax_rev_county_base_off=off_pre_exp_base*tax_rate

egen tot_tax_rev_base=sum(tax_rev_county_base), by(year mode)
egen tot_tax_rev_base_off=sum(tax_rev_county_base_off*(mode==1)*nb_hh), by(year)


format tot_exp_base %15.5g

// keep relevant data
contract year mode tot_exp tot_exp_all tot_exp_base tot_tax_rev tot_tax_rev_all tot_tax_rev_base tot_tax_rev_off tot_tax_rev_all_off tot_tax_rev_base_off tot_exp_base_off tot_exp_off tot_exp_all_off
drop _freq

egen tot_online=sum(tot_exp), by(year)
gen tot_all=tot_online+tot_exp_off

gen online_mode_share=tot_exp/tot_online
gen offline_share=1-tot_online/tot_all

egen online_tax_rev=sum(tot_tax_rev), by(year)
gen all_tax_rev=online_tax_rev+tot_tax_rev_off

egen tot_online_all=sum(tot_exp_all), by(year)

gen tot_all_all=tot_online_all+tot_exp_all_off

gen online_mode_share_all=tot_exp_all/tot_online_all
gen offline_share_all=1-tot_online_all/tot_all_all

egen online_tax_rev_all=sum(tot_tax_rev_all), by(year)
gen all_tax_rev_all=online_tax_rev_all+tot_tax_rev_all_off

egen tot_online_base=sum(tot_exp_base), by(year)
gen tot_all_base=tot_online_base+tot_exp_base_off

gen online_mode_share_base=tot_exp_base/tot_online_base
gen offline_share_base=1-tot_online_base/tot_all_base

egen online_tax_rev_base=sum(tot_tax_rev_base), by(year)
gen all_tax_rev_base=online_tax_rev_base+tot_tax_rev_base_off

contract year mode online_mode_share* offline_share* online_tax_rev* all_tax_rev* tot_exp* tot_tax_rev*
drop _freq

// save offline year level data.
preserve 
contract year tot_tax_rev_off tot_tax_rev_base_off tot_tax_rev_all_off tot_exp_off tot_exp_base_off tot_exp_all_off
drop _freq
save "tmp.dta", replace
restore

reshape wide online_mode_share* tot_exp tot_exp_all tot_exp_base tot_tax_rev tot_tax_rev_base tot_tax_rev_all, i(year online_tax_rev* all_tax_rev*) j(mode) 

merge 1:1 year using "tmp.dta"
drop _merge
erase "tmp.dta"

// change units
replace online_tax_rev=online_tax_rev/1000000
replace online_tax_rev_all=online_tax_rev_all/1000000
replace online_tax_rev_base=online_tax_rev_base/1000000

replace all_tax_rev=all_tax_rev/1000000
replace all_tax_rev_all=all_tax_rev_all/1000000
replace all_tax_rev_base=all_tax_rev_base/1000000

replace tot_exp1=tot_exp1/1000000
replace tot_exp2=tot_exp2/1000000
replace tot_exp3=tot_exp3/1000000

replace tot_exp_all1=tot_exp_all1/1000000
replace tot_exp_all2=tot_exp_all2/1000000
replace tot_exp_all3=tot_exp_all3/1000000

replace tot_exp_base1=tot_exp_base1/1000000
replace tot_exp_base2=tot_exp_base2/1000000
replace tot_exp_base3=tot_exp_base3/1000000

replace tot_tax_rev1=tot_tax_rev1/1000000
replace tot_tax_rev2=tot_tax_rev2/1000000
replace tot_tax_rev3=tot_tax_rev3/1000000

replace tot_tax_rev_all1=tot_tax_rev_all1/1000000
replace tot_tax_rev_all2=tot_tax_rev_all2/1000000
replace tot_tax_rev_all3=tot_tax_rev_all3/1000000

replace tot_tax_rev_base1=tot_tax_rev_base1/1000000
replace tot_tax_rev_base2=tot_tax_rev_base2/1000000
replace tot_tax_rev_base3=tot_tax_rev_base3/1000000

replace tot_exp_off=tot_exp_off/1000000
replace tot_exp_base_off =tot_exp_base_off/1000000
replace tot_exp_all_off=tot_exp_all_off/1000000

replace tot_tax_rev_off=tot_tax_rev_off/1000000
replace tot_tax_rev_all_off=tot_tax_rev_all_off/1000000
replace tot_tax_rev_base_off=tot_tax_rev_base_off/1000000


// save data to bring to table 10.
keep if year==1999 | year==2006 | year==2012 | year==2018

preserve
keep *_all *_base year online_mode_share_all* online_mode_share_base* 
outsheet using  "Analysis/Output/share_taxes.csv",  replace comma names
restore 

keep *_all *_base year online_mode_share_all* online_mode_share_base* tot_exp* tot_tax_rev*
outsheet using  "Analysis/Output/share_taxes2.csv",  replace comma names

